/****************************************************************************
** Meta object code from reading C++ file 'docksettings.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../docksettings.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'docksettings.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4dock12DockSettingsE_t {};
} // unnamed namespace

template <> constexpr inline auto dock::DockSettings::qt_create_metaobjectdata<qt_meta_tag_ZN4dock12DockSettingsE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dock::DockSettings",
        "dockSizeChanged",
        "",
        "size",
        "hideModeChanged",
        "HideMode",
        "mode",
        "positionChanged",
        "Position",
        "position",
        "itemAlignmentChanged",
        "ItemAlignment",
        "alignment",
        "indicatorStyleChanged",
        "IndicatorStyle",
        "style",
        "pluginsVisibleChanged",
        "QVariantMap",
        "pluginsVisible",
        "showInPrimaryChanged",
        "showInPrimary",
        "lockedChanged",
        "locked",
        "dockSize",
        "hidemode",
        "itemAlignment",
        "indicatorStyle"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'dockSizeChanged'
        QtMocHelpers::SignalData<void(uint)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Signal 'hideModeChanged'
        QtMocHelpers::SignalData<void(HideMode)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Signal 'positionChanged'
        QtMocHelpers::SignalData<void(Position)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 9 },
        }}),
        // Signal 'itemAlignmentChanged'
        QtMocHelpers::SignalData<void(ItemAlignment)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 12 },
        }}),
        // Signal 'indicatorStyleChanged'
        QtMocHelpers::SignalData<void(IndicatorStyle)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 14, 15 },
        }}),
        // Signal 'pluginsVisibleChanged'
        QtMocHelpers::SignalData<void(const QVariantMap &)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Signal 'showInPrimaryChanged'
        QtMocHelpers::SignalData<void(bool)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 20 },
        }}),
        // Signal 'lockedChanged'
        QtMocHelpers::SignalData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 22 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'dockSize'
        QtMocHelpers::PropertyData<uint>(23, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'hidemode'
        QtMocHelpers::PropertyData<HideMode>(24, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'position'
        QtMocHelpers::PropertyData<Position>(9, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
        // property 'itemAlignment'
        QtMocHelpers::PropertyData<ItemAlignment>(25, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 3),
        // property 'indicatorStyle'
        QtMocHelpers::PropertyData<IndicatorStyle>(26, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 4),
        // property 'pluginsVisible'
        QtMocHelpers::PropertyData<QVariantMap>(18, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 5),
        // property 'showInPrimary'
        QtMocHelpers::PropertyData<bool>(20, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 6),
        // property 'locked'
        QtMocHelpers::PropertyData<bool>(22, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 7),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DockSettings, qt_meta_tag_ZN4dock12DockSettingsE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dock::DockSettings::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock12DockSettingsE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock12DockSettingsE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4dock12DockSettingsE_t>.metaTypes,
    nullptr
} };

void dock::DockSettings::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DockSettings *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->dockSizeChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 1: _t->hideModeChanged((*reinterpret_cast<std::add_pointer_t<HideMode>>(_a[1]))); break;
        case 2: _t->positionChanged((*reinterpret_cast<std::add_pointer_t<Position>>(_a[1]))); break;
        case 3: _t->itemAlignmentChanged((*reinterpret_cast<std::add_pointer_t<ItemAlignment>>(_a[1]))); break;
        case 4: _t->indicatorStyleChanged((*reinterpret_cast<std::add_pointer_t<IndicatorStyle>>(_a[1]))); break;
        case 5: _t->pluginsVisibleChanged((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1]))); break;
        case 6: _t->showInPrimaryChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 7: _t->lockedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DockSettings::*)(uint )>(_a, &DockSettings::dockSizeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockSettings::*)(HideMode )>(_a, &DockSettings::hideModeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockSettings::*)(Position )>(_a, &DockSettings::positionChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockSettings::*)(ItemAlignment )>(_a, &DockSettings::itemAlignmentChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockSettings::*)(IndicatorStyle )>(_a, &DockSettings::indicatorStyleChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockSettings::*)(const QVariantMap & )>(_a, &DockSettings::pluginsVisibleChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockSettings::*)(bool )>(_a, &DockSettings::showInPrimaryChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockSettings::*)(bool )>(_a, &DockSettings::lockedChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->dockSize(); break;
        case 1: *reinterpret_cast<HideMode*>(_v) = _t->hideMode(); break;
        case 2: *reinterpret_cast<Position*>(_v) = _t->position(); break;
        case 3: *reinterpret_cast<ItemAlignment*>(_v) = _t->itemAlignment(); break;
        case 4: *reinterpret_cast<IndicatorStyle*>(_v) = _t->indicatorStyle(); break;
        case 5: *reinterpret_cast<QVariantMap*>(_v) = _t->pluginsVisible(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->showInPrimary(); break;
        case 7: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDockSize(*reinterpret_cast<uint*>(_v)); break;
        case 1: _t->setHideMode(*reinterpret_cast<HideMode*>(_v)); break;
        case 2: _t->setPosition(*reinterpret_cast<Position*>(_v)); break;
        case 3: _t->setItemAlignment(*reinterpret_cast<ItemAlignment*>(_v)); break;
        case 4: _t->setIndicatorStyle(*reinterpret_cast<IndicatorStyle*>(_v)); break;
        case 5: _t->setPluginsVisible(*reinterpret_cast<QVariantMap*>(_v)); break;
        case 6: _t->setShowInPrimary(*reinterpret_cast<bool*>(_v)); break;
        case 7: _t->setLocked(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dock::DockSettings::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dock::DockSettings::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock12DockSettingsE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dock::DockSettings::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void dock::DockSettings::dockSizeChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void dock::DockSettings::hideModeChanged(HideMode _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void dock::DockSettings::positionChanged(Position _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dock::DockSettings::itemAlignmentChanged(ItemAlignment _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void dock::DockSettings::indicatorStyleChanged(IndicatorStyle _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void dock::DockSettings::pluginsVisibleChanged(const QVariantMap & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void dock::DockSettings::showInPrimaryChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void dock::DockSettings::lockedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}
QT_WARNING_POP
