/****************************************************************************
** Meta object code from reading C++ file 'pluginmanagerextension_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../pluginmanagerextension_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'pluginmanagerextension_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18PluginScaleManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto PluginScaleManager::qt_create_metaobjectdata<qt_meta_tag_ZN18PluginScaleManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PluginScaleManager",
        "QML.Element",
        "auto",
        "pluginScaleChanged",
        "",
        "uint32_t",
        "scale",
        "pluginScale"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pluginScaleChanged'
        QtMocHelpers::SignalData<void(uint32_t)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pluginScale'
        QtMocHelpers::PropertyData<uint32_t>(7, 0x80000000 | 5, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PluginScaleManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PluginScaleManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandCompositorExtensionTemplate<PluginScaleManager>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PluginScaleManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PluginScaleManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18PluginScaleManagerE_t>.metaTypes,
    nullptr
} };

void PluginScaleManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginScaleManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pluginScaleChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PluginScaleManager::*)(uint32_t )>(_a, &PluginScaleManager::pluginScaleChanged, 0))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint32_t*>(_v) = _t->pluginScale(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setPluginScale(*reinterpret_cast<uint32_t*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PluginScaleManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginScaleManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18PluginScaleManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWaylandServer::wp_fractional_scale_manager_v1"))
        return static_cast< QtWaylandServer::wp_fractional_scale_manager_v1*>(this);
    return QWaylandCompositorExtensionTemplate<PluginScaleManager>::qt_metacast(_clname);
}

int PluginScaleManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandCompositorExtensionTemplate<PluginScaleManager>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void PluginScaleManager::pluginScaleChanged(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN11PluginScaleE_t {};
} // unnamed namespace

template <> constexpr inline auto PluginScale::qt_create_metaobjectdata<qt_meta_tag_ZN11PluginScaleE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PluginScale"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<PluginScale, qt_meta_tag_ZN11PluginScaleE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject PluginScale::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandCompositorExtensionTemplate<PluginScale>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PluginScaleE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PluginScaleE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PluginScaleE_t>.metaTypes,
    nullptr
} };

void PluginScale::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginScale *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *PluginScale::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginScale::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PluginScaleE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWaylandServer::wp_fractional_scale_v1"))
        return static_cast< QtWaylandServer::wp_fractional_scale_v1*>(this);
    return QWaylandCompositorExtensionTemplate<PluginScale>::qt_metacast(_clname);
}

int PluginScale::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandCompositorExtensionTemplate<PluginScale>::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN13PluginManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto PluginManager::qt_create_metaobjectdata<qt_meta_tag_ZN13PluginManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PluginManager",
        "QML.Element",
        "auto",
        "pluginPopupCreated",
        "",
        "PluginPopup*",
        "pluginCloseQuickPanelPopup",
        "pluginSurfaceCreated",
        "PluginSurface*",
        "pluginSurfaceDestroyed",
        "messageRequest",
        "msg",
        "dockSizeChanged",
        "requestShutdown",
        "type",
        "moveXEmbedWindowRequested",
        "uint32_t",
        "wid",
        "pluginId",
        "itemKey",
        "dx",
        "dy",
        "QQuickWindow*",
        "anchorWindow",
        "onFontChanged",
        "onActiveColorChanged",
        "onThemeChanged",
        "onTextInputSurfaceEnabled",
        "QWaylandSurface*",
        "surface",
        "updateDockOverflowState",
        "state",
        "setPopupMinHeight",
        "height",
        "notifyXEmbedWindowMoveResult",
        "result",
        "sendRightClickForSurface",
        "dockPosition",
        "dockColorTheme",
        "dockSize",
        "QSize"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pluginPopupCreated'
        QtMocHelpers::SignalData<void(PluginPopup *)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 4 },
        }}),
        // Signal 'pluginCloseQuickPanelPopup'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'pluginSurfaceCreated'
        QtMocHelpers::SignalData<void(PluginSurface *)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 4 },
        }}),
        // Signal 'pluginSurfaceDestroyed'
        QtMocHelpers::SignalData<void(PluginSurface *)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 4 },
        }}),
        // Signal 'messageRequest'
        QtMocHelpers::SignalData<void(PluginSurface *, const QString &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 4 }, { QMetaType::QString, 11 },
        }}),
        // Signal 'dockSizeChanged'
        QtMocHelpers::SignalData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'requestShutdown'
        QtMocHelpers::SignalData<void(const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 },
        }}),
        // Signal 'moveXEmbedWindowRequested'
        QtMocHelpers::SignalData<void(uint32_t, const QString &, const QString &, double, double, QQuickWindow *)>(15, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::QString, 18 }, { QMetaType::QString, 19 }, { QMetaType::Double, 20 },
            { QMetaType::Double, 21 }, { 0x80000000 | 22, 23 },
        }}),
        // Slot 'onFontChanged'
        QtMocHelpers::SlotData<void()>(24, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onActiveColorChanged'
        QtMocHelpers::SlotData<void()>(25, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onThemeChanged'
        QtMocHelpers::SlotData<void()>(26, 4, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onTextInputSurfaceEnabled'
        QtMocHelpers::SlotData<void(QWaylandSurface *)>(27, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 28, 29 },
        }}),
        // Method 'updateDockOverflowState'
        QtMocHelpers::MethodData<void(int)>(30, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 31 },
        }}),
        // Method 'setPopupMinHeight'
        QtMocHelpers::MethodData<void(int)>(32, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 33 },
        }}),
        // Method 'notifyXEmbedWindowMoveResult'
        QtMocHelpers::MethodData<void(uint32_t, bool)>(34, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 16, 17 }, { QMetaType::Bool, 35 },
        }}),
        // Method 'sendRightClickForSurface'
        QtMocHelpers::MethodData<void()>(36, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'dockPosition'
        QtMocHelpers::PropertyData<uint32_t>(37, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'dockColorTheme'
        QtMocHelpers::PropertyData<uint32_t>(38, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'dockSize'
        QtMocHelpers::PropertyData<QSize>(39, 0x80000000 | 40, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PluginManager, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PluginManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandCompositorExtensionTemplate<PluginManager>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PluginManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PluginManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13PluginManagerE_t>.metaTypes,
    nullptr
} };

void PluginManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pluginPopupCreated((*reinterpret_cast<std::add_pointer_t<PluginPopup*>>(_a[1]))); break;
        case 1: _t->pluginCloseQuickPanelPopup(); break;
        case 2: _t->pluginSurfaceCreated((*reinterpret_cast<std::add_pointer_t<PluginSurface*>>(_a[1]))); break;
        case 3: _t->pluginSurfaceDestroyed((*reinterpret_cast<std::add_pointer_t<PluginSurface*>>(_a[1]))); break;
        case 4: _t->messageRequest((*reinterpret_cast<std::add_pointer_t<PluginSurface*>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 5: _t->dockSizeChanged(); break;
        case 6: _t->requestShutdown((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->moveXEmbedWindowRequested((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<double>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QQuickWindow*>>(_a[6]))); break;
        case 8: _t->onFontChanged(); break;
        case 9: _t->onActiveColorChanged(); break;
        case 10: _t->onThemeChanged(); break;
        case 11: _t->onTextInputSurfaceEnabled((*reinterpret_cast<std::add_pointer_t<QWaylandSurface*>>(_a[1]))); break;
        case 12: _t->updateDockOverflowState((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 13: _t->setPopupMinHeight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 14: _t->notifyXEmbedWindowMoveResult((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 15: _t->sendRightClickForSurface(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PluginPopup* >(); break;
            }
            break;
        case 2:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PluginSurface* >(); break;
            }
            break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PluginSurface* >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< PluginSurface* >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 5:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickWindow* >(); break;
            }
            break;
        case 11:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QWaylandSurface* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PluginManager::*)(PluginPopup * )>(_a, &PluginManager::pluginPopupCreated, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginManager::*)()>(_a, &PluginManager::pluginCloseQuickPanelPopup, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginManager::*)(PluginSurface * )>(_a, &PluginManager::pluginSurfaceCreated, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginManager::*)(PluginSurface * )>(_a, &PluginManager::pluginSurfaceDestroyed, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginManager::*)(PluginSurface * , const QString & )>(_a, &PluginManager::messageRequest, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginManager::*)()>(_a, &PluginManager::dockSizeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginManager::*)(const QString & )>(_a, &PluginManager::requestShutdown, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginManager::*)(uint32_t , const QString & , const QString & , double , double , QQuickWindow * )>(_a, &PluginManager::moveXEmbedWindowRequested, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint32_t*>(_v) = _t->dockPosition(); break;
        case 1: *reinterpret_cast<uint32_t*>(_v) = _t->dockColorTheme(); break;
        case 2: *reinterpret_cast<QSize*>(_v) = _t->dockSize(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setDockPosition(*reinterpret_cast<uint32_t*>(_v)); break;
        case 1: _t->setDockColorTheme(*reinterpret_cast<uint32_t*>(_v)); break;
        case 2: _t->setDockSize(*reinterpret_cast<QSize*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PluginManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PluginManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWaylandServer::plugin_manager_v1"))
        return static_cast< QtWaylandServer::plugin_manager_v1*>(this);
    return QWaylandCompositorExtensionTemplate<PluginManager>::qt_metacast(_clname);
}

int PluginManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandCompositorExtensionTemplate<PluginManager>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void PluginManager::pluginPopupCreated(PluginPopup * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void PluginManager::pluginCloseQuickPanelPopup()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PluginManager::pluginSurfaceCreated(PluginSurface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void PluginManager::pluginSurfaceDestroyed(PluginSurface * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PluginManager::messageRequest(PluginSurface * _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void PluginManager::dockSizeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void PluginManager::requestShutdown(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void PluginManager::moveXEmbedWindowRequested(uint32_t _t1, const QString & _t2, const QString & _t3, double _t4, double _t5, QQuickWindow * _t6)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2, _t3, _t4, _t5, _t6);
}
namespace {
struct qt_meta_tag_ZN13PluginSurfaceE_t {};
} // unnamed namespace

template <> constexpr inline auto PluginSurface::qt_create_metaobjectdata<qt_meta_tag_ZN13PluginSurfaceE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PluginSurface",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "PluginSurface is not creatable in QML.",
        "itemActiveChanged",
        "",
        "heightChanged",
        "widthChanged",
        "recvMouseEvent",
        "QEvent::Type",
        "type",
        "marginsChanged",
        "aboutToDestroy",
        "updatePluginGeometry",
        "QRect",
        "geometry",
        "setGlobalPos",
        "QPoint",
        "pos",
        "setAnchorWindow",
        "QQuickWindow*",
        "window",
        "pluginId",
        "itemKey",
        "pluginFlags",
        "uint32_t",
        "pluginType",
        "pluginSizePolicy",
        "displayName",
        "height",
        "width",
        "isItemActive",
        "dccIcon",
        "margins"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'itemActiveChanged'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'recvMouseEvent'
        QtMocHelpers::SignalData<void(QEvent::Type)>(11, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 13 },
        }}),
        // Signal 'marginsChanged'
        QtMocHelpers::SignalData<void()>(14, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'aboutToDestroy'
        QtMocHelpers::SignalData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'updatePluginGeometry'
        QtMocHelpers::MethodData<void(const QRect &)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'setGlobalPos'
        QtMocHelpers::MethodData<void(const QPoint &)>(19, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 20, 21 },
        }}),
        // Method 'setAnchorWindow'
        QtMocHelpers::MethodData<void(QQuickWindow *)>(22, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 23, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'pluginId'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'itemKey'
        QtMocHelpers::PropertyData<QString>(26, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'pluginFlags'
        QtMocHelpers::PropertyData<uint32_t>(27, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'pluginType'
        QtMocHelpers::PropertyData<uint32_t>(29, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'pluginSizePolicy'
        QtMocHelpers::PropertyData<uint32_t>(30, 0x80000000 | 28, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Constant),
        // property 'displayName'
        QtMocHelpers::PropertyData<QString>(31, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'height'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags, 1),
        // property 'width'
        QtMocHelpers::PropertyData<int>(33, QMetaType::Int, QMC::DefaultPropertyFlags, 2),
        // property 'isItemActive'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'dccIcon'
        QtMocHelpers::PropertyData<QString>(35, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'margins'
        QtMocHelpers::PropertyData<int>(36, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<PluginSurface, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PluginSurface::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandShellSurfaceTemplate<PluginSurface>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PluginSurfaceE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PluginSurfaceE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN13PluginSurfaceE_t>.metaTypes,
    nullptr
} };

void PluginSurface::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginSurface *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->itemActiveChanged(); break;
        case 1: _t->heightChanged(); break;
        case 2: _t->widthChanged(); break;
        case 3: _t->recvMouseEvent((*reinterpret_cast<std::add_pointer_t<QEvent::Type>>(_a[1]))); break;
        case 4: _t->marginsChanged(); break;
        case 5: _t->aboutToDestroy(); break;
        case 6: _t->updatePluginGeometry((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 7: _t->setGlobalPos((*reinterpret_cast<std::add_pointer_t<QPoint>>(_a[1]))); break;
        case 8: _t->setAnchorWindow((*reinterpret_cast<std::add_pointer_t<QQuickWindow*>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 8:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QQuickWindow* >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PluginSurface::*)()>(_a, &PluginSurface::itemActiveChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginSurface::*)()>(_a, &PluginSurface::heightChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginSurface::*)()>(_a, &PluginSurface::widthChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginSurface::*)(QEvent::Type )>(_a, &PluginSurface::recvMouseEvent, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginSurface::*)()>(_a, &PluginSurface::marginsChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginSurface::*)()>(_a, &PluginSurface::aboutToDestroy, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->pluginId(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->itemKey(); break;
        case 2: *reinterpret_cast<uint32_t*>(_v) = _t->pluginFlags(); break;
        case 3: *reinterpret_cast<uint32_t*>(_v) = _t->pluginType(); break;
        case 4: *reinterpret_cast<uint32_t*>(_v) = _t->pluginSizePolicy(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->displayName(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->height(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->width(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->isItemActive(); break;
        case 9: *reinterpret_cast<QString*>(_v) = _t->dccIcon(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->margins(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 8: _t->setItemActive(*reinterpret_cast<bool*>(_v)); break;
        case 10: _t->setMargins(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PluginSurface::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginSurface::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN13PluginSurfaceE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWaylandServer::plugin"))
        return static_cast< QtWaylandServer::plugin*>(this);
    return QWaylandShellSurfaceTemplate<PluginSurface>::qt_metacast(_clname);
}

int PluginSurface::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandShellSurfaceTemplate<PluginSurface>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    return _id;
}

// SIGNAL 0
void PluginSurface::itemActiveChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PluginSurface::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PluginSurface::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PluginSurface::recvMouseEvent(QEvent::Type _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void PluginSurface::marginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PluginSurface::aboutToDestroy()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}
namespace {
struct qt_meta_tag_ZN11PluginPopupE_t {};
} // unnamed namespace

template <> constexpr inline auto PluginPopup::qt_create_metaobjectdata<qt_meta_tag_ZN11PluginPopupE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PluginPopup",
        "QML.Element",
        "auto",
        "QML.Creatable",
        "false",
        "QML.UncreatableReason",
        "PluginPopup is not creatable in QML.",
        "aboutToDestroy",
        "",
        "xChanged",
        "yChanged",
        "heightChanged",
        "widthChanged",
        "cursorShapeRequested",
        "cursorShape",
        "close",
        "updatePluginGeometry",
        "QRect",
        "geometry",
        "setEmbedPanelMinHeight",
        "height",
        "x",
        "int32_t",
        "y",
        "pluginId",
        "itemKey",
        "popupType",
        "width"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'aboutToDestroy'
        QtMocHelpers::SignalData<void()>(7, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xChanged'
        QtMocHelpers::SignalData<void()>(9, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'yChanged'
        QtMocHelpers::SignalData<void()>(10, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'heightChanged'
        QtMocHelpers::SignalData<void()>(11, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'widthChanged'
        QtMocHelpers::SignalData<void()>(12, 8, QMC::AccessPublic, QMetaType::Void),
        // Signal 'cursorShapeRequested'
        QtMocHelpers::SignalData<void(int)>(13, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 14 },
        }}),
        // Method 'close'
        QtMocHelpers::MethodData<void()>(15, 8, QMC::AccessPublic, QMetaType::Void),
        // Method 'updatePluginGeometry'
        QtMocHelpers::MethodData<void(const QRect &)>(16, 8, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 17, 18 },
        }}),
        // Method 'setEmbedPanelMinHeight'
        QtMocHelpers::MethodData<void(int)>(19, 8, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 20 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'x'
        QtMocHelpers::PropertyData<int32_t>(21, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 1),
        // property 'y'
        QtMocHelpers::PropertyData<int32_t>(23, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 2),
        // property 'pluginId'
        QtMocHelpers::PropertyData<QString>(24, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'itemKey'
        QtMocHelpers::PropertyData<QString>(25, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'popupType'
        QtMocHelpers::PropertyData<int32_t>(26, 0x80000000 | 22, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'height'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags, 3),
        // property 'width'
        QtMocHelpers::PropertyData<int>(27, QMetaType::Int, QMC::DefaultPropertyFlags, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
            {    5,    6 },
    });
    return QtMocHelpers::metaObjectData<PluginPopup, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PluginPopup::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandShellSurfaceTemplate<PluginPopup>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PluginPopupE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PluginPopupE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN11PluginPopupE_t>.metaTypes,
    nullptr
} };

void PluginPopup::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginPopup *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->aboutToDestroy(); break;
        case 1: _t->xChanged(); break;
        case 2: _t->yChanged(); break;
        case 3: _t->heightChanged(); break;
        case 4: _t->widthChanged(); break;
        case 5: _t->cursorShapeRequested((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->close(); break;
        case 7: _t->updatePluginGeometry((*reinterpret_cast<std::add_pointer_t<QRect>>(_a[1]))); break;
        case 8: _t->setEmbedPanelMinHeight((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)()>(_a, &PluginPopup::aboutToDestroy, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)()>(_a, &PluginPopup::xChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)()>(_a, &PluginPopup::yChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)()>(_a, &PluginPopup::heightChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)()>(_a, &PluginPopup::widthChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (PluginPopup::*)(int )>(_a, &PluginPopup::cursorShapeRequested, 5))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int32_t*>(_v) = _t->x(); break;
        case 1: *reinterpret_cast<int32_t*>(_v) = _t->y(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->pluginId(); break;
        case 3: *reinterpret_cast<QString*>(_v) = _t->itemKey(); break;
        case 4: *reinterpret_cast<int32_t*>(_v) = _t->popupType(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->height(); break;
        case 6: *reinterpret_cast<int*>(_v) = _t->width(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setX(*reinterpret_cast<int32_t*>(_v)); break;
        case 1: _t->setY(*reinterpret_cast<int32_t*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *PluginPopup::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginPopup::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN11PluginPopupE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWaylandServer::plugin_popup"))
        return static_cast< QtWaylandServer::plugin_popup*>(this);
    return QWaylandShellSurfaceTemplate<PluginPopup>::qt_metacast(_clname);
}

int PluginPopup::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandShellSurfaceTemplate<PluginPopup>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void PluginPopup::aboutToDestroy()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void PluginPopup::xChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void PluginPopup::yChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void PluginPopup::heightChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void PluginPopup::widthChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void PluginPopup::cursorShapeRequested(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN27PluginManagerQuickExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto PluginManagerQuickExtension::qt_create_metaobjectdata<qt_meta_tag_ZN27PluginManagerQuickExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PluginManagerQuickExtension",
        "DefaultProperty",
        "data",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 3, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PluginManagerQuickExtension, qt_meta_tag_ZN27PluginManagerQuickExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PluginManagerQuickExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<PluginManager::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27PluginManagerQuickExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27PluginManagerQuickExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN27PluginManagerQuickExtensionE_t>.metaTypes,
    nullptr
} };

void PluginManagerQuickExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginManagerQuickExtension *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
}

const QMetaObject *PluginManagerQuickExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginManagerQuickExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN27PluginManagerQuickExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return PluginManager::qt_metacast(_clname);
}

int PluginManagerQuickExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PluginManager::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN32PluginScaleManagerQuickExtensionE_t {};
} // unnamed namespace

template <> constexpr inline auto PluginScaleManagerQuickExtension::qt_create_metaobjectdata<qt_meta_tag_ZN32PluginScaleManagerQuickExtensionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "PluginScaleManagerQuickExtension",
        "DefaultProperty",
        "data",
        "QQmlListProperty<QObject>"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'data'
        QtMocHelpers::PropertyData<QQmlListProperty<QObject>>(2, 0x80000000 | 3, QMC::Readable | QMC::Scriptable | QMC::Stored | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PluginScaleManagerQuickExtension, qt_meta_tag_ZN32PluginScaleManagerQuickExtensionE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject PluginScaleManagerQuickExtension::staticMetaObject = { {
    QMetaObject::SuperData::link<PluginScaleManager::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32PluginScaleManagerQuickExtensionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32PluginScaleManagerQuickExtensionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN32PluginScaleManagerQuickExtensionE_t>.metaTypes,
    nullptr
} };

void PluginScaleManagerQuickExtension::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PluginScaleManagerQuickExtension *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QQmlListProperty<QObject>*>(_v) = _t->data(); break;
        default: break;
        }
    }
}

const QMetaObject *PluginScaleManagerQuickExtension::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *PluginScaleManagerQuickExtension::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN32PluginScaleManagerQuickExtensionE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return PluginScaleManager::qt_metacast(_clname);
}

int PluginScaleManagerQuickExtension::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = PluginScaleManager::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
