/****************************************************************************
** Meta object code from reading C++ file 'constants.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../constants.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'constants.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4dockE_t {};
} // unnamed namespace

template <> constexpr inline auto dock::qt_create_metaobjectdata<qt_meta_tag_ZN4dockE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dock",
        "QML.Element",
        "Dock",
        "SIZE",
        "MIN_DOCK_SIZE",
        "DEFAULT_DOCK_SIZE",
        "MAX_DOCK_SIZE",
        "MIN_DOCK_TASKMANAGER_ICON_SIZE",
        "MAX_DOCK_TASKMANAGER_ICON_SIZE",
        "IndicatorStyle",
        "Fashion",
        "Efficient",
        "ItemAlignment",
        "CenterAlignment",
        "LeftAlignment",
        "ColorTheme",
        "Light",
        "Dark",
        "HideMode",
        "KeepShowing",
        "KeepHidden",
        "SmartHide",
        "Position",
        "Top",
        "Right",
        "Bottom",
        "Left",
        "HideState",
        "Unknown",
        "Show",
        "Hide",
        "AniAction",
        "AA_Show",
        "AA_Hide",
        "TrayPopupType",
        "TrayPopupTypePanel",
        "TrayPopupTypeTooltip",
        "TrayPopupTypeMenu",
        "TrayPopupTypeEmbed",
        "TrayPopupTypeSubPopup",
        "TrayPluginType",
        "Tray",
        "Fixed",
        "Quick",
        "TrayPluginSizePolicy",
        "System",
        "Custom",
        "OverFlowState",
        "OverflowNotExist",
        "OverflowExist",
        "OverflowAll"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'SIZE'
        QtMocHelpers::EnumData<SIZE>(3, 3, QMC::EnumFlags{}).add({
            {    4, SIZE::MIN_DOCK_SIZE },
            {    5, SIZE::DEFAULT_DOCK_SIZE },
            {    6, SIZE::MAX_DOCK_SIZE },
            {    7, SIZE::MIN_DOCK_TASKMANAGER_ICON_SIZE },
            {    8, SIZE::MAX_DOCK_TASKMANAGER_ICON_SIZE },
        }),
        // enum 'IndicatorStyle'
        QtMocHelpers::EnumData<IndicatorStyle>(9, 9, QMC::EnumFlags{}).add({
            {   10, IndicatorStyle::Fashion },
            {   11, IndicatorStyle::Efficient },
        }),
        // enum 'ItemAlignment'
        QtMocHelpers::EnumData<ItemAlignment>(12, 12, QMC::EnumFlags{}).add({
            {   13, ItemAlignment::CenterAlignment },
            {   14, ItemAlignment::LeftAlignment },
        }),
        // enum 'ColorTheme'
        QtMocHelpers::EnumData<ColorTheme>(15, 15, QMC::EnumFlags{}).add({
            {   16, ColorTheme::Light },
            {   17, ColorTheme::Dark },
        }),
        // enum 'HideMode'
        QtMocHelpers::EnumData<HideMode>(18, 18, QMC::EnumFlags{}).add({
            {   19, HideMode::KeepShowing },
            {   20, HideMode::KeepHidden },
            {   21, HideMode::SmartHide },
        }),
        // enum 'Position'
        QtMocHelpers::EnumData<Position>(22, 22, QMC::EnumFlags{}).add({
            {   23, Position::Top },
            {   24, Position::Right },
            {   25, Position::Bottom },
            {   26, Position::Left },
        }),
        // enum 'HideState'
        QtMocHelpers::EnumData<HideState>(27, 27, QMC::EnumFlags{}).add({
            {   28, HideState::Unknown },
            {   29, HideState::Show },
            {   30, HideState::Hide },
        }),
        // enum 'AniAction'
        QtMocHelpers::EnumData<AniAction>(31, 31, QMC::EnumFlags{}).add({
            {   32, AniAction::AA_Show },
            {   33, AniAction::AA_Hide },
        }),
        // enum 'TrayPopupType'
        QtMocHelpers::EnumData<TrayPopupType>(34, 34, QMC::EnumFlags{}).add({
            {   35, TrayPopupType::TrayPopupTypePanel },
            {   36, TrayPopupType::TrayPopupTypeTooltip },
            {   37, TrayPopupType::TrayPopupTypeMenu },
            {   38, TrayPopupType::TrayPopupTypeEmbed },
            {   39, TrayPopupType::TrayPopupTypeSubPopup },
        }),
        // enum 'TrayPluginType'
        QtMocHelpers::EnumData<TrayPluginType>(40, 40, QMC::EnumFlags{}).add({
            {   41, TrayPluginType::Tray },
            {   42, TrayPluginType::Fixed },
            {   43, TrayPluginType::Quick },
        }),
        // enum 'TrayPluginSizePolicy'
        QtMocHelpers::EnumData<TrayPluginSizePolicy>(44, 44, QMC::EnumFlags{}).add({
            {   45, TrayPluginSizePolicy::System },
            {   46, TrayPluginSizePolicy::Custom },
        }),
        // enum 'OverFlowState'
        QtMocHelpers::EnumData<OverFlowState>(47, 47, QMC::EnumFlags{}).add({
            {   48, OverFlowState::OverflowNotExist },
            {   49, OverFlowState::OverflowExist },
            {   50, OverFlowState::OverflowAll },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<void, qt_meta_tag_ZN4dockE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}

static constexpr auto qt_staticMetaObjectContent_ZN4dockE =
    dock::qt_create_metaobjectdata<qt_meta_tag_ZN4dockE_t>();
static constexpr auto qt_staticMetaObjectStaticContent_ZN4dockE =
    qt_staticMetaObjectContent_ZN4dockE.staticData;
static constexpr auto qt_staticMetaObjectRelocatingContent_ZN4dockE =
    qt_staticMetaObjectContent_ZN4dockE.relocatingData;

Q_CONSTINIT const QMetaObject dock::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent_ZN4dockE.stringdata,
    qt_staticMetaObjectStaticContent_ZN4dockE.data,
    nullptr,
    nullptr,
    qt_staticMetaObjectRelocatingContent_ZN4dockE.metaTypes,
    nullptr
} };

QT_WARNING_POP
