/****************************************************************************
** Meta object code from reading C++ file 'notifyserverapplet.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../notifyserverapplet.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notifyserverapplet.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12notification18NotifyServerAppletE_t {};
} // unnamed namespace

template <> constexpr inline auto notification::NotifyServerApplet::qt_create_metaobjectdata<qt_meta_tag_ZN12notification18NotifyServerAppletE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "notification::NotifyServerApplet",
        "notificationStateChanged",
        "",
        "id",
        "processedType",
        "actionInvoked",
        "bubbleId",
        "actionKey",
        "notificationClosed",
        "reason",
        "appValue",
        "QVariant",
        "appId",
        "configItem",
        "removeNotification",
        "removeNotifications",
        "appName",
        "removeExpiredNotifications",
        "setBlockClosedId"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'notificationStateChanged'
        QtMocHelpers::SignalData<void(qint64, int)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::Int, 4 },
        }}),
        // Slot 'actionInvoked'
        QtMocHelpers::SlotData<void(qint64, uint, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::UInt, 6 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'actionInvoked'
        QtMocHelpers::SlotData<void(qint64, const QString &)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::QString, 7 },
        }}),
        // Slot 'notificationClosed'
        QtMocHelpers::SlotData<void(qint64, uint, uint)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::UInt, 6 }, { QMetaType::UInt, 9 },
        }}),
        // Slot 'appValue'
        QtMocHelpers::SlotData<QVariant(const QString &, int)>(10, 2, QMC::AccessPublic, 0x80000000 | 11, {{
            { QMetaType::QString, 12 }, { QMetaType::Int, 13 },
        }}),
        // Slot 'removeNotification'
        QtMocHelpers::SlotData<void(qint64)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 },
        }}),
        // Slot 'removeNotifications'
        QtMocHelpers::SlotData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 16 },
        }}),
        // Slot 'removeNotifications'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'removeExpiredNotifications'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setBlockClosedId'
        QtMocHelpers::SlotData<void(qint64)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NotifyServerApplet, qt_meta_tag_ZN12notification18NotifyServerAppletE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject notification::NotifyServerApplet::staticMetaObject = { {
    QMetaObject::SuperData::link<ds::DApplet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12notification18NotifyServerAppletE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12notification18NotifyServerAppletE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12notification18NotifyServerAppletE_t>.metaTypes,
    nullptr
} };

void notification::NotifyServerApplet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotifyServerApplet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->notificationStateChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 1: _t->actionInvoked((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 2: _t->actionInvoked((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 3: _t->notificationClosed((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 4: { QVariant _r = _t->appValue((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 5: _t->removeNotification((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 6: _t->removeNotifications((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->removeNotifications(); break;
        case 8: _t->removeExpiredNotifications(); break;
        case 9: _t->setBlockClosedId((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NotifyServerApplet::*)(qint64 , int )>(_a, &NotifyServerApplet::notificationStateChanged, 0))
            return;
    }
}

const QMetaObject *notification::NotifyServerApplet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *notification::NotifyServerApplet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12notification18NotifyServerAppletE_t>.strings))
        return static_cast<void*>(this);
    return ds::DApplet::qt_metacast(_clname);
}

int notification::NotifyServerApplet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ds::DApplet::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void notification::NotifyServerApplet::notificationStateChanged(qint64 _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
QT_WARNING_POP
