// SPDX-FileCopyrightText: 2023 UnionTech Software Technology Co., Ltd.
//
// SPDX-License-Identifier: GPL-3.0-or-later

#include "dstypes.h"

#include <QMap>

DS_BEGIN_NAMESPACE

Types::Types(QObject *parent)
    : QObject(parent)
{

}

DS_END_NAMESPACE
