/****************************************************************************
** Meta object code from reading C++ file 'notifystagingmodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../notifystagingmodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notifystagingmodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12notifycenter18NotifyStagingModelE_t {};
} // unnamed namespace

template <> constexpr inline auto notifycenter::NotifyStagingModel::qt_create_metaobjectdata<qt_meta_tag_ZN12notifycenter18NotifyStagingModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "notifycenter::NotifyStagingModel",
        "QML.Element",
        "auto",
        "push",
        "",
        "NotifyEntity",
        "entity",
        "replace",
        "doEntityReceived",
        "id",
        "onEntityClosed",
        "closeNotify",
        "reason",
        "invokeNotify",
        "actionId",
        "open",
        "close"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'push'
        QtMocHelpers::SlotData<void(const NotifyEntity &)>(3, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'replace'
        QtMocHelpers::SlotData<void(const NotifyEntity &)>(7, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 5, 6 },
        }}),
        // Slot 'doEntityReceived'
        QtMocHelpers::SlotData<void(qint64)>(8, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 9 },
        }}),
        // Slot 'onEntityClosed'
        QtMocHelpers::SlotData<void(qint64)>(10, 4, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::LongLong, 9 },
        }}),
        // Method 'closeNotify'
        QtMocHelpers::MethodData<void(qint64, int)>(11, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 9 }, { QMetaType::Int, 12 },
        }}),
        // Method 'invokeNotify'
        QtMocHelpers::MethodData<void(qint64, const QString &)>(13, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 9 }, { QMetaType::QString, 14 },
        }}),
        // Method 'open'
        QtMocHelpers::MethodData<void()>(15, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'close'
        QtMocHelpers::MethodData<void()>(16, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<NotifyStagingModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject notifycenter::NotifyStagingModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QAbstractListModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12notifycenter18NotifyStagingModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12notifycenter18NotifyStagingModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12notifycenter18NotifyStagingModelE_t>.metaTypes,
    nullptr
} };

void notifycenter::NotifyStagingModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotifyStagingModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->push((*reinterpret_cast<std::add_pointer_t<NotifyEntity>>(_a[1]))); break;
        case 1: _t->replace((*reinterpret_cast<std::add_pointer_t<NotifyEntity>>(_a[1]))); break;
        case 2: _t->doEntityReceived((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 3: _t->onEntityClosed((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 4: _t->closeNotify((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 5: _t->invokeNotify((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 6: _t->open(); break;
        case 7: _t->close(); break;
        default: ;
        }
    }
}

const QMetaObject *notifycenter::NotifyStagingModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *notifycenter::NotifyStagingModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12notifycenter18NotifyStagingModelE_t>.strings))
        return static_cast<void*>(this);
    return QAbstractListModel::qt_metacast(_clname);
}

int notifycenter::NotifyStagingModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QAbstractListModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
