/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.dock1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "dockfrontadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class DockFrontAdaptor
 */

DockFrontAdaptor::DockFrontAdaptor(dock::DockDBusProxy *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

DockFrontAdaptor::~DockFrontAdaptor()
{
    // destructor
}

QRect DockFrontAdaptor::geometry() const
{
    // get the value of property geometry
    return qvariant_cast< QRect >(parent()->property("geometry"));
}

bool DockFrontAdaptor::showInPrimary() const
{
    // get the value of property showInPrimary
    return qvariant_cast< bool >(parent()->property("showInPrimary"));
}

void DockFrontAdaptor::setShowInPrimary(bool value)
{
    // set the value of property showInPrimary
    parent()->setProperty("showInPrimary", QVariant::fromValue(value));
}

QStringList DockFrontAdaptor::GetLoadedPlugins()
{
    // handle method call org.deepin.dde.Dock1.GetLoadedPlugins
    return parent()->GetLoadedPlugins();
}

void DockFrontAdaptor::ReloadPlugins()
{
    // handle method call org.deepin.dde.Dock1.ReloadPlugins
    parent()->ReloadPlugins();
}

void DockFrontAdaptor::callShow()
{
    // handle method call org.deepin.dde.Dock1.callShow
    parent()->callShow();
}

QString DockFrontAdaptor::getPluginKey(const QString &pluginName)
{
    // handle method call org.deepin.dde.Dock1.getPluginKey
    return parent()->getPluginKey(pluginName);
}

bool DockFrontAdaptor::getPluginVisible(const QString &pluginName)
{
    // handle method call org.deepin.dde.Dock1.getPluginVisible
    return parent()->getPluginVisible(pluginName);
}

DockItemInfos DockFrontAdaptor::plugins()
{
    // handle method call org.deepin.dde.Dock1.plugins
    return parent()->plugins();
}

void DockFrontAdaptor::resizeDock(int offset, bool dragging)
{
    // handle method call org.deepin.dde.Dock1.resizeDock
    parent()->resizeDock(offset, dragging);
}

void DockFrontAdaptor::setItemOnDock(const QString &settingKey, const QString &itemKey, bool visible)
{
    // handle method call org.deepin.dde.Dock1.setItemOnDock
    parent()->setItemOnDock(settingKey, itemKey, visible);
}

void DockFrontAdaptor::setPluginVisible(const QString &pluginName, bool visible)
{
    // handle method call org.deepin.dde.Dock1.setPluginVisible
    parent()->setPluginVisible(pluginName, visible);
}


#include "moc_dockfrontadaptor.cpp"
