/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.dde.daemon.Dock1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#include "dockdaemonadaptor.h"
#include <QtCore/QMetaObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>

/*
 * Implementation of adaptor class DockDaemonAdaptor
 */

DockDaemonAdaptor::DockDaemonAdaptor(dock::DockDBusProxy *parent)
    : QDBusAbstractAdaptor(parent)
{
    // constructor
    setAutoRelaySignals(true);
}

DockDaemonAdaptor::~DockDaemonAdaptor()
{
    // destructor
}

int DockDaemonAdaptor::displayMode() const
{
    // get the value of property DisplayMode
    return qvariant_cast< int >(parent()->property("DisplayMode"));
}

void DockDaemonAdaptor::setDisplayMode(int value)
{
    // set the value of property DisplayMode
    parent()->setProperty("DisplayMode", QVariant::fromValue(value));
}

QRect DockDaemonAdaptor::frontendWindowRect() const
{
    // get the value of property FrontendWindowRect
    return qvariant_cast< QRect >(parent()->property("FrontendWindowRect"));
}

int DockDaemonAdaptor::hideMode() const
{
    // get the value of property HideMode
    return qvariant_cast< int >(parent()->property("HideMode"));
}

void DockDaemonAdaptor::setHideMode(int value)
{
    // set the value of property HideMode
    parent()->setProperty("HideMode", QVariant::fromValue(value));
}

int DockDaemonAdaptor::hideState() const
{
    // get the value of property HideState
    return qvariant_cast< int >(parent()->property("HideState"));
}

bool DockDaemonAdaptor::locked() const
{
    // get the value of property Locked
    return qvariant_cast< bool >(parent()->property("Locked"));
}

void DockDaemonAdaptor::setLocked(bool value)
{
    // set the value of property Locked
    parent()->setProperty("Locked", QVariant::fromValue(value));
}

int DockDaemonAdaptor::position() const
{
    // get the value of property Position
    return qvariant_cast< int >(parent()->property("Position"));
}

void DockDaemonAdaptor::setPosition(int value)
{
    // set the value of property Position
    parent()->setProperty("Position", QVariant::fromValue(value));
}

uint DockDaemonAdaptor::windowSizeEfficient() const
{
    // get the value of property WindowSizeEfficient
    return qvariant_cast< uint >(parent()->property("WindowSizeEfficient"));
}

void DockDaemonAdaptor::setWindowSizeEfficient(uint value)
{
    // set the value of property WindowSizeEfficient
    parent()->setProperty("WindowSizeEfficient", QVariant::fromValue(value));
}

uint DockDaemonAdaptor::windowSizeFashion() const
{
    // get the value of property WindowSizeFashion
    return qvariant_cast< uint >(parent()->property("WindowSizeFashion"));
}

void DockDaemonAdaptor::setWindowSizeFashion(uint value)
{
    // set the value of property WindowSizeFashion
    parent()->setProperty("WindowSizeFashion", QVariant::fromValue(value));
}

void DockDaemonAdaptor::ActivateWindow(uint win)
{
    // handle method call org.deepin.dde.daemon.Dock1.ActivateWindow
    parent()->ActivateWindow(win);
}

bool DockDaemonAdaptor::IsDocked(const QString &desktopFile)
{
    // handle method call org.deepin.dde.daemon.Dock1.IsDocked
    return parent()->IsDocked(desktopFile);
}

bool DockDaemonAdaptor::RequestDock(const QString &desktopFile, int index)
{
    // handle method call org.deepin.dde.daemon.Dock1.RequestDock
    return parent()->RequestDock(desktopFile, index);
}

bool DockDaemonAdaptor::RequestUndock(const QString &desktopFile)
{
    // handle method call org.deepin.dde.daemon.Dock1.RequestUndock
    return parent()->RequestUndock(desktopFile);
}


#include "moc_dockdaemonadaptor.cpp"
