/****************************************************************************
** Meta object code from reading C++ file 'dsquickdrag_p.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../quick/dsquickdrag_p.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dsquickdrag_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2ds10DQuickDragE_t {};
} // unnamed namespace

template <> constexpr inline auto ds::DQuickDrag::qt_create_metaobjectdata<qt_meta_tag_ZN2ds10DQuickDragE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ds::DQuickDrag",
        "activeChanged",
        "",
        "startDragPointChanged",
        "overlayChanged",
        "hotSpotScaleChanged",
        "currentDragPointChanged",
        "overlayWindowChanged",
        "isDraggingChanged",
        "active",
        "overlay",
        "QQmlComponent*",
        "hotSpotScale",
        "QSizeF",
        "startDragPoint",
        "QPoint",
        "currentDragPoint",
        "overlayWindow",
        "QWindow*",
        "isDragging"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'activeChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'startDragPointChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'overlayChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'hotSpotScaleChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'currentDragPointChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'overlayWindowChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'isDraggingChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'active'
        QtMocHelpers::PropertyData<bool>(9, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 0),
        // property 'overlay'
        QtMocHelpers::PropertyData<QQmlComponent*>(10, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
        // property 'hotSpotScale'
        QtMocHelpers::PropertyData<QSizeF>(12, 0x80000000 | 13, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 3),
        // property 'startDragPoint'
        QtMocHelpers::PropertyData<QPoint>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
        // property 'currentDragPoint'
        QtMocHelpers::PropertyData<QPoint>(16, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 4),
        // property 'overlayWindow'
        QtMocHelpers::PropertyData<QWindow*>(17, 0x80000000 | 18, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 5),
        // property 'isDragging'
        QtMocHelpers::PropertyData<bool>(19, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Final, 6),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DQuickDrag, qt_meta_tag_ZN2ds10DQuickDragE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ds::DQuickDrag::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2ds10DQuickDragE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2ds10DQuickDragE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2ds10DQuickDragE_t>.metaTypes,
    nullptr
} };

void ds::DQuickDrag::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DQuickDrag *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->activeChanged(); break;
        case 1: _t->startDragPointChanged(); break;
        case 2: _t->overlayChanged(); break;
        case 3: _t->hotSpotScaleChanged(); break;
        case 4: _t->currentDragPointChanged(); break;
        case 5: _t->overlayWindowChanged(); break;
        case 6: _t->isDraggingChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DQuickDrag::*)()>(_a, &DQuickDrag::activeChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDrag::*)()>(_a, &DQuickDrag::startDragPointChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDrag::*)()>(_a, &DQuickDrag::overlayChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDrag::*)()>(_a, &DQuickDrag::hotSpotScaleChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDrag::*)()>(_a, &DQuickDrag::currentDragPointChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDrag::*)()>(_a, &DQuickDrag::overlayWindowChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DQuickDrag::*)()>(_a, &DQuickDrag::isDraggingChanged, 6))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QQmlComponent* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<bool*>(_v) = _t->active(); break;
        case 1: *reinterpret_cast<QQmlComponent**>(_v) = _t->overlay(); break;
        case 2: *reinterpret_cast<QSizeF*>(_v) = _t->hotSpotScale(); break;
        case 3: *reinterpret_cast<QPoint*>(_v) = _t->startDragPoint(); break;
        case 4: *reinterpret_cast<QPoint*>(_v) = _t->currentDragPoint(); break;
        case 5: *reinterpret_cast<QWindow**>(_v) = _t->overlayWindow(); break;
        case 6: *reinterpret_cast<bool*>(_v) = _t->isDragging(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setActive(*reinterpret_cast<bool*>(_v)); break;
        case 1: _t->setOverlay(*reinterpret_cast<QQmlComponent**>(_v)); break;
        case 2: _t->setHotSpotScale(*reinterpret_cast<QSizeF*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 2: _t->resetHotSpotScale(); break;
        default: break;
        }
    }
}

const QMetaObject *ds::DQuickDrag::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ds::DQuickDrag::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2ds10DQuickDragE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Dtk::Core::DObject"))
        return static_cast< Dtk::Core::DObject*>(this);
    return QObject::qt_metacast(_clname);
}

int ds::DQuickDrag::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void ds::DQuickDrag::activeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ds::DQuickDrag::startDragPointChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ds::DQuickDrag::overlayChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ds::DQuickDrag::hotSpotScaleChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ds::DQuickDrag::currentDragPointChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ds::DQuickDrag::overlayWindowChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ds::DQuickDrag::isDraggingChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
