/****************************************************************************
** Meta object code from reading C++ file 'displaymodeapplet.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../displaymodeapplet.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'displaymodeapplet.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3osd6DPItemE_t {};
} // unnamed namespace

template <> constexpr inline auto osd::DPItem::qt_create_metaobjectdata<qt_meta_tag_ZN3osd6DPItemE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "osd::DPItem",
        "textChanged",
        "",
        "iconNameChanged",
        "modeChanged",
        "text",
        "name",
        "iconName",
        "mode",
        "key",
        "DPMode",
        "Merge",
        "Extend",
        "Single"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'textChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconNameChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'modeChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'text'
        QtMocHelpers::PropertyData<QString>(5, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(6, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'iconName'
        QtMocHelpers::PropertyData<QString>(7, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'mode'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Constant),
        // property 'key'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Constant),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DPMode'
        QtMocHelpers::EnumData<enum DPMode>(10, 10, QMC::EnumFlags{}).add({
            {   11, DPMode::Merge },
            {   12, DPMode::Extend },
            {   13, DPMode::Single },
        }),
    };
    return QtMocHelpers::metaObjectData<DPItem, qt_meta_tag_ZN3osd6DPItemE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject osd::DPItem::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3osd6DPItemE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3osd6DPItemE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3osd6DPItemE_t>.metaTypes,
    nullptr
} };

void osd::DPItem::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DPItem *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->textChanged(); break;
        case 1: _t->iconNameChanged(); break;
        case 2: _t->modeChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DPItem::*)()>(_a, &DPItem::textChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DPItem::*)()>(_a, &DPItem::iconNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DPItem::*)()>(_a, &DPItem::modeChanged, 2))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->text(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->iconName(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->mode(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->key(); break;
        default: break;
        }
    }
}

const QMetaObject *osd::DPItem::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *osd::DPItem::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3osd6DPItemE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int osd::DPItem::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 3;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void osd::DPItem::textChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void osd::DPItem::iconNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void osd::DPItem::modeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace {
struct qt_meta_tag_ZN3osd17DisPlayModeAppletE_t {};
} // unnamed namespace

template <> constexpr inline auto osd::DisPlayModeApplet::qt_create_metaobjectdata<qt_meta_tag_ZN3osd17DisPlayModeAppletE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "osd::DisPlayModeApplet",
        "currentPlanItemChanged",
        "",
        "planItemsChanged",
        "stateChanged",
        "sync",
        "next",
        "doAction",
        "state",
        "currentPlanItem",
        "DPItem*",
        "planItems",
        "QQmlListProperty<DPItem>"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'currentPlanItemChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'planItemsChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'stateChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'sync'
        QtMocHelpers::MethodData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'next'
        QtMocHelpers::MethodData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'doAction'
        QtMocHelpers::MethodData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'state'
        QtMocHelpers::PropertyData<int>(8, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Final, 2),
        // property 'currentPlanItem'
        QtMocHelpers::PropertyData<DPItem*>(9, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 0),
        // property 'planItems'
        QtMocHelpers::PropertyData<QQmlListProperty<DPItem>>(11, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final, 1),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DisPlayModeApplet, qt_meta_tag_ZN3osd17DisPlayModeAppletE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject osd::DisPlayModeApplet::staticMetaObject = { {
    QMetaObject::SuperData::link<ds::DApplet::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3osd17DisPlayModeAppletE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3osd17DisPlayModeAppletE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3osd17DisPlayModeAppletE_t>.metaTypes,
    nullptr
} };

void osd::DisPlayModeApplet::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DisPlayModeApplet *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->currentPlanItemChanged(); break;
        case 1: _t->planItemsChanged(); break;
        case 2: _t->stateChanged(); break;
        case 3: _t->sync(); break;
        case 4: _t->next(); break;
        case 5: _t->doAction(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DisPlayModeApplet::*)()>(_a, &DisPlayModeApplet::currentPlanItemChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisPlayModeApplet::*)()>(_a, &DisPlayModeApplet::planItemsChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DisPlayModeApplet::*)()>(_a, &DisPlayModeApplet::stateChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< DPItem* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->state(); break;
        case 1: *reinterpret_cast<DPItem**>(_v) = _t->currentPlanItem(); break;
        case 2: *reinterpret_cast<QQmlListProperty<DPItem>*>(_v) = _t->planItems(); break;
        default: break;
        }
    }
}

const QMetaObject *osd::DisPlayModeApplet::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *osd::DisPlayModeApplet::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3osd17DisPlayModeAppletE_t>.strings))
        return static_cast<void*>(this);
    return ds::DApplet::qt_metacast(_clname);
}

int osd::DisPlayModeApplet::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = ds::DApplet::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void osd::DisPlayModeApplet::currentPlanItemChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void osd::DisPlayModeApplet::planItemsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void osd::DisPlayModeApplet::stateChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
