/****************************************************************************
** Meta object code from reading C++ file 'quickpanelproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../quickpanelproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'quickpanelproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4dock20QuickPanelProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto dock::QuickPanelProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN4dock20QuickPanelProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dock::QuickPanelProxyModel",
        "QML.Element",
        "QuickPanelProxyModel",
        "trayItemSurfaceChanged",
        "",
        "trayItemPluginIdChanged",
        "trayPluginModelChanged",
        "updateTrayItemSurface",
        "getTitle",
        "pluginId",
        "isQuickPanelPopup",
        "itemKey",
        "openSystemSettings",
        "trayItemPluginId",
        "trayItemSurface",
        "trayPluginModel",
        "QAbstractItemModel*"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'trayItemSurfaceChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trayItemPluginIdChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'trayPluginModelChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'updateTrayItemSurface'
        QtMocHelpers::SlotData<void()>(7, 4, QMC::AccessPrivate, QMetaType::Void),
        // Method 'getTitle'
        QtMocHelpers::MethodData<QString(const QString &) const>(8, 4, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 9 },
        }}),
        // Method 'isQuickPanelPopup'
        QtMocHelpers::MethodData<bool(const QString &, const QString &) const>(10, 4, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 9 }, { QMetaType::QString, 11 },
        }}),
        // Method 'openSystemSettings'
        QtMocHelpers::MethodData<void()>(12, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'trayItemPluginId'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final, 1),
        // property 'trayItemSurface'
        QtMocHelpers::PropertyData<QObject*>(14, QMetaType::QObjectStar, QMC::DefaultPropertyFlags | QMC::Final, 0),
        // property 'trayPluginModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<QuickPanelProxyModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject dock::QuickPanelProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock20QuickPanelProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock20QuickPanelProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4dock20QuickPanelProxyModelE_t>.metaTypes,
    nullptr
} };

void dock::QuickPanelProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<QuickPanelProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->trayItemSurfaceChanged(); break;
        case 1: _t->trayItemPluginIdChanged(); break;
        case 2: _t->trayPluginModelChanged(); break;
        case 3: _t->updateTrayItemSurface(); break;
        case 4: { QString _r = _t->getTitle((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 5: { bool _r = _t->isQuickPanelPopup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 6: _t->openSystemSettings(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (QuickPanelProxyModel::*)()>(_a, &QuickPanelProxyModel::trayItemSurfaceChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickPanelProxyModel::*)()>(_a, &QuickPanelProxyModel::trayItemPluginIdChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (QuickPanelProxyModel::*)()>(_a, &QuickPanelProxyModel::trayPluginModelChanged, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->trayItemPluginId(); break;
        case 1: *reinterpret_cast<QObject**>(_v) = _t->trayItemSurface(); break;
        case 2: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->trayPluginModel(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTrayItemPluginId(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setTrayPluginModel(*reinterpret_cast<QAbstractItemModel**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dock::QuickPanelProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dock::QuickPanelProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock20QuickPanelProxyModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int dock::QuickPanelProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void dock::QuickPanelProxyModel::trayItemSurfaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dock::QuickPanelProxyModel::trayItemPluginIdChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dock::QuickPanelProxyModel::trayPluginModelChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
