/****************************************************************************
** Meta object code from reading C++ file 'desktopfileabstractparser.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../desktopfileabstractparser.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'desktopfileabstractparser.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4dock25DesktopfileAbstractParserE_t {};
} // unnamed namespace

template <> constexpr inline auto dock::DesktopfileAbstractParser::qt_create_metaobjectdata<qt_meta_tag_ZN4dock25DesktopfileAbstractParserE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dock::DesktopfileAbstractParser",
        "nameChanged",
        "",
        "iconChanged",
        "actionsChanged",
        "genericNameChanged",
        "dockedChanged",
        "xDeepinVendorChanged",
        "valiedChanged",
        "desktopIcon",
        "id",
        "name",
        "isDocked",
        "genericName",
        "actions",
        "QList<std::pair<QString,QString>>",
        "xDeepinVendor"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'nameChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'iconChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'actionsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'genericNameChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'dockedChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'xDeepinVendorChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'valiedChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'id'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags),
        // property 'name'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags, 0),
        // property 'desktopIcon'
        QtMocHelpers::PropertyData<QString>(9, QMetaType::QString, QMC::DefaultPropertyFlags, 0x70000000 | 9),
        // property 'isDocked'
        QtMocHelpers::PropertyData<bool>(12, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'genericName'
        QtMocHelpers::PropertyData<QString>(13, QMetaType::QString, QMC::DefaultPropertyFlags, 3),
        // property 'actions'
        QtMocHelpers::PropertyData<QList<std::pair<QString,QString>>>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 2),
        // property 'xDeepinVendor'
        QtMocHelpers::PropertyData<QString>(16, QMetaType::QString, QMC::DefaultPropertyFlags, 5),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DesktopfileAbstractParser, qt_meta_tag_ZN4dock25DesktopfileAbstractParserE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dock::DesktopfileAbstractParser::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock25DesktopfileAbstractParserE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock25DesktopfileAbstractParserE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4dock25DesktopfileAbstractParserE_t>.metaTypes,
    nullptr
} };

void dock::DesktopfileAbstractParser::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DesktopfileAbstractParser *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->nameChanged(); break;
        case 1: _t->iconChanged(); break;
        case 2: _t->actionsChanged(); break;
        case 3: _t->genericNameChanged(); break;
        case 4: _t->dockedChanged(); break;
        case 5: _t->xDeepinVendorChanged(); break;
        case 6: _t->valiedChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DesktopfileAbstractParser::*)()>(_a, &DesktopfileAbstractParser::nameChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopfileAbstractParser::*)()>(_a, &DesktopfileAbstractParser::iconChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopfileAbstractParser::*)()>(_a, &DesktopfileAbstractParser::actionsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopfileAbstractParser::*)()>(_a, &DesktopfileAbstractParser::genericNameChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopfileAbstractParser::*)()>(_a, &DesktopfileAbstractParser::dockedChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopfileAbstractParser::*)()>(_a, &DesktopfileAbstractParser::xDeepinVendorChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DesktopfileAbstractParser::*)()>(_a, &DesktopfileAbstractParser::valiedChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->id(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->name(); break;
        case 2: *reinterpret_cast<QString*>(_v) = _t->desktopIcon(); break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->isDocked(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->genericName(); break;
        case 5: *reinterpret_cast<QList<std::pair<QString,QString>>*>(_v) = _t->actions(); break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->xDeepinVendor(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 3: _t->setDocked(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dock::DesktopfileAbstractParser::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dock::DesktopfileAbstractParser::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock25DesktopfileAbstractParserE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int dock::DesktopfileAbstractParser::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 7;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    }
    return _id;
}

// SIGNAL 0
void dock::DesktopfileAbstractParser::nameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dock::DesktopfileAbstractParser::iconChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void dock::DesktopfileAbstractParser::actionsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void dock::DesktopfileAbstractParser::genericNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void dock::DesktopfileAbstractParser::dockedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void dock::DesktopfileAbstractParser::xDeepinVendorChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void dock::DesktopfileAbstractParser::valiedChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
namespace CheckNotifySignalValidity_ZN4dock25DesktopfileAbstractParserE {
template<typename T> using has_nullary_desktopIcon = decltype(std::declval<T>().desktopIcon());
template<typename T> using has_unary_desktopIcon = decltype(std::declval<T>().desktopIcon(std::declval<QString>()));
static_assert(qxp::is_detected_v<has_nullary_desktopIcon, dock::DesktopfileAbstractParser> || qxp::is_detected_v<has_unary_desktopIcon, dock::DesktopfileAbstractParser>,
              "NOTIFY signal desktopIcon does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
