/****************************************************************************
** Meta object code from reading C++ file 'popupwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../popupwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'popupwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2ds11PopupWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto ds::PopupWindow::qt_create_metaobjectdata<qt_meta_tag_ZN2ds11PopupWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ds::PopupWindow",
        "QML.Element",
        "PopupWindow",
        "x11GrabFocusTransitionChanged",
        "",
        "x11FocusOutByGrab",
        "x11FocusInByUngrab",
        "setWindowGeometry",
        "px",
        "py",
        "pw",
        "ph",
        "transientParentChanged",
        "transientParent",
        "QWindow*",
        "x11GrabFocusTransition"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'x11GrabFocusTransitionChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'x11FocusOutByGrab'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'x11FocusInByUngrab'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Method 'setWindowGeometry'
        QtMocHelpers::MethodData<void(int, int, int, int)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 }, { QMetaType::Int, 11 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'transientParent'
        QtMocHelpers::PropertyData<QWindow*>(13, 0x80000000 | 14, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0x70000000 | 12),
        // property 'x11GrabFocusTransition'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags, 0),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<PopupWindow, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject ds::PopupWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QQuickApplicationWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2ds11PopupWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2ds11PopupWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2ds11PopupWindowE_t>.metaTypes,
    nullptr
} };

void ds::PopupWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<PopupWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->x11GrabFocusTransitionChanged(); break;
        case 1: _t->x11FocusOutByGrab(); break;
        case 2: _t->x11FocusInByUngrab(); break;
        case 3: _t->setWindowGeometry((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (PopupWindow::*)()>(_a, &PopupWindow::x11GrabFocusTransitionChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (PopupWindow::*)()>(_a, &PopupWindow::x11FocusOutByGrab, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (PopupWindow::*)()>(_a, &PopupWindow::x11FocusInByUngrab, 2))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWindow* >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QWindow**>(_v) = _t->transientParent(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->x11GrabFocusTransition(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setTransientParent(*reinterpret_cast<QWindow**>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *ds::PopupWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ds::PopupWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2ds11PopupWindowE_t>.strings))
        return static_cast<void*>(this);
    return QQuickApplicationWindow::qt_metacast(_clname);
}

int ds::PopupWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QQuickApplicationWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void ds::PopupWindow::x11GrabFocusTransitionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ds::PopupWindow::x11FocusOutByGrab()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ds::PopupWindow::x11FocusInByUngrab()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
namespace CheckNotifySignalValidity_ZN2ds11PopupWindowE {
template<typename T> using has_nullary_transientParentChanged = decltype(std::declval<T>().transientParentChanged());
template<typename T> using has_unary_transientParentChanged = decltype(std::declval<T>().transientParentChanged(std::declval<QWindow*>()));
static_assert(qxp::is_detected_v<has_nullary_transientParentChanged, ds::PopupWindow> || qxp::is_detected_v<has_unary_transientParentChanged, ds::PopupWindow>,
              "NOTIFY signal transientParentChanged does not exist in class (or is private in its parent)");
}
QT_WARNING_POP
