/****************************************************************************
** Meta object code from reading C++ file 'x11dockhelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../x11dockhelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'x11dockhelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4dock14XcbEventFilterE_t {};
} // unnamed namespace

template <> constexpr inline auto dock::XcbEventFilter::qt_create_metaobjectdata<qt_meta_tag_ZN4dock14XcbEventFilterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dock::XcbEventFilter",
        "windowClientListChanged",
        "",
        "windowPropertyChanged",
        "xcb_window_t",
        "window",
        "xcb_atom_t",
        "atom",
        "windowGeometryChanged",
        "currentWorkspaceChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'windowClientListChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'windowPropertyChanged'
        QtMocHelpers::SignalData<void(xcb_window_t, xcb_atom_t)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 6, 7 },
        }}),
        // Signal 'windowGeometryChanged'
        QtMocHelpers::SignalData<void(xcb_window_t)>(8, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Signal 'currentWorkspaceChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<XcbEventFilter, qt_meta_tag_ZN4dock14XcbEventFilterE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dock::XcbEventFilter::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock14XcbEventFilterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock14XcbEventFilterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4dock14XcbEventFilterE_t>.metaTypes,
    nullptr
} };

void dock::XcbEventFilter::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<XcbEventFilter *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->windowClientListChanged(); break;
        case 1: _t->windowPropertyChanged((*reinterpret_cast<std::add_pointer_t<xcb_window_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<xcb_atom_t>>(_a[2]))); break;
        case 2: _t->windowGeometryChanged((*reinterpret_cast<std::add_pointer_t<xcb_window_t>>(_a[1]))); break;
        case 3: _t->currentWorkspaceChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (XcbEventFilter::*)()>(_a, &XcbEventFilter::windowClientListChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (XcbEventFilter::*)(xcb_window_t , xcb_atom_t )>(_a, &XcbEventFilter::windowPropertyChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (XcbEventFilter::*)(xcb_window_t )>(_a, &XcbEventFilter::windowGeometryChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (XcbEventFilter::*)()>(_a, &XcbEventFilter::currentWorkspaceChanged, 3))
            return;
    }
}

const QMetaObject *dock::XcbEventFilter::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dock::XcbEventFilter::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock14XcbEventFilterE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QAbstractNativeEventFilter"))
        return static_cast< QAbstractNativeEventFilter*>(this);
    return QObject::qt_metacast(_clname);
}

int dock::XcbEventFilter::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void dock::XcbEventFilter::windowClientListChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dock::XcbEventFilter::windowPropertyChanged(xcb_window_t _t1, xcb_atom_t _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void dock::XcbEventFilter::windowGeometryChanged(xcb_window_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void dock::XcbEventFilter::currentWorkspaceChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}
namespace {
struct qt_meta_tag_ZN4dock13X11DockHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto dock::X11DockHelper::qt_create_metaobjectdata<qt_meta_tag_ZN4dock13X11DockHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dock::X11DockHelper",
        "onHideModeChanged",
        "",
        "HideMode",
        "mode",
        "onWindowClientListChanged",
        "onWindowAdded",
        "xcb_window_t",
        "window",
        "onWindowPropertyChanged",
        "xcb_atom_t",
        "atom",
        "onWindowGeometryChanged",
        "onWindowWorkspaceChanged",
        "updateWindowHideState",
        "updateDockArea",
        "onShowingDesktopChanged",
        "showing"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'onHideModeChanged'
        QtMocHelpers::SlotData<void(HideMode)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
        // Slot 'onWindowClientListChanged'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onWindowAdded'
        QtMocHelpers::SlotData<void(xcb_window_t)>(6, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'onWindowPropertyChanged'
        QtMocHelpers::SlotData<void(xcb_window_t, xcb_atom_t)>(9, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 }, { 0x80000000 | 10, 11 },
        }}),
        // Slot 'onWindowGeometryChanged'
        QtMocHelpers::SlotData<void(xcb_window_t)>(12, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'onWindowWorkspaceChanged'
        QtMocHelpers::SlotData<void(xcb_window_t)>(13, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'updateWindowHideState'
        QtMocHelpers::SlotData<void(xcb_window_t)>(14, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 7, 8 },
        }}),
        // Slot 'updateDockArea'
        QtMocHelpers::SlotData<void()>(15, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'onShowingDesktopChanged'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<X11DockHelper, qt_meta_tag_ZN4dock13X11DockHelperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dock::X11DockHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<DockHelper::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock13X11DockHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock13X11DockHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4dock13X11DockHelperE_t>.metaTypes,
    nullptr
} };

void dock::X11DockHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<X11DockHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->onHideModeChanged((*reinterpret_cast<std::add_pointer_t<HideMode>>(_a[1]))); break;
        case 1: _t->onWindowClientListChanged(); break;
        case 2: _t->onWindowAdded((*reinterpret_cast<std::add_pointer_t<xcb_window_t>>(_a[1]))); break;
        case 3: _t->onWindowPropertyChanged((*reinterpret_cast<std::add_pointer_t<xcb_window_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<xcb_atom_t>>(_a[2]))); break;
        case 4: _t->onWindowGeometryChanged((*reinterpret_cast<std::add_pointer_t<xcb_window_t>>(_a[1]))); break;
        case 5: _t->onWindowWorkspaceChanged((*reinterpret_cast<std::add_pointer_t<xcb_window_t>>(_a[1]))); break;
        case 6: _t->updateWindowHideState((*reinterpret_cast<std::add_pointer_t<xcb_window_t>>(_a[1]))); break;
        case 7: _t->updateDockArea(); break;
        case 8: _t->onShowingDesktopChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *dock::X11DockHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dock::X11DockHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock13X11DockHelperE_t>.strings))
        return static_cast<void*>(this);
    return DockHelper::qt_metacast(_clname);
}

int dock::X11DockHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DockHelper::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN4dock17X11DockWakeUpAreaE_t {};
} // unnamed namespace

template <> constexpr inline auto dock::X11DockWakeUpArea::qt_create_metaobjectdata<qt_meta_tag_ZN4dock17X11DockWakeUpAreaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dock::X11DockWakeUpArea"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<X11DockWakeUpArea, qt_meta_tag_ZN4dock17X11DockWakeUpAreaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dock::X11DockWakeUpArea::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock17X11DockWakeUpAreaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock17X11DockWakeUpAreaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4dock17X11DockWakeUpAreaE_t>.metaTypes,
    nullptr
} };

void dock::X11DockWakeUpArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<X11DockWakeUpArea *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dock::X11DockWakeUpArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dock::X11DockWakeUpArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock17X11DockWakeUpAreaE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "DockWakeUpArea"))
        return static_cast< DockWakeUpArea*>(this);
    return QObject::qt_metacast(_clname);
}

int dock::X11DockWakeUpArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
