/****************************************************************************
** Meta object code from reading C++ file 'applicationmanager1interface.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "applicationmanager1interface.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'applicationmanager1interface.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN18ApplicationManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto ApplicationManager::qt_create_metaobjectdata<qt_meta_tag_ZN18ApplicationManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ApplicationManager",
        "Identify",
        "QDBusPendingReply<QString,QDBusObjectPath,ObjectInterfaceMap>",
        "",
        "QDBusUnixFileDescriptor",
        "pidfd",
        "QDBusReply<QString>",
        "QDBusObjectPath&",
        "instance",
        "ObjectInterfaceMap&",
        "application_instance_info",
        "ReloadApplications",
        "QDBusPendingReply<>",
        "addUserApplication",
        "QDBusPendingReply<QString>",
        "QVariantMap",
        "desktop_file",
        "name",
        "deleteUserApplication",
        "app_id",
        "executeCommand",
        "QDBusPendingReply<QDBusObjectPath>",
        "program",
        "arguments",
        "type",
        "runId",
        "QStringMap",
        "envVars",
        "workdir",
        "List",
        "QList<QDBusObjectPath>"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'Identify'
        QtMocHelpers::SlotData<QDBusPendingReply<QString,QDBusObjectPath,ObjectInterfaceMap>(const QDBusUnixFileDescriptor &)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { 0x80000000 | 4, 5 },
        }}),
        // Slot 'Identify'
        QtMocHelpers::SlotData<QDBusReply<QString>(const QDBusUnixFileDescriptor &, QDBusObjectPath &, ObjectInterfaceMap &)>(1, 3, QMC::AccessPublic, 0x80000000 | 6, {{
            { 0x80000000 | 4, 5 }, { 0x80000000 | 7, 8 }, { 0x80000000 | 9, 10 },
        }}),
        // Slot 'ReloadApplications'
        QtMocHelpers::SlotData<QDBusPendingReply<>()>(11, 3, QMC::AccessPublic, 0x80000000 | 12),
        // Slot 'addUserApplication'
        QtMocHelpers::SlotData<QDBusPendingReply<QString>(const QVariantMap &, const QString &)>(13, 3, QMC::AccessPublic, 0x80000000 | 14, {{
            { 0x80000000 | 15, 16 }, { QMetaType::QString, 17 },
        }}),
        // Slot 'deleteUserApplication'
        QtMocHelpers::SlotData<QDBusPendingReply<>(const QString &)>(18, 3, QMC::AccessPublic, 0x80000000 | 12, {{
            { QMetaType::QString, 19 },
        }}),
        // Slot 'executeCommand'
        QtMocHelpers::SlotData<QDBusPendingReply<QDBusObjectPath>(const QString &, const QStringList &, const QString &, const QString &, const QStringMap &, const QString &)>(20, 3, QMC::AccessPublic, 0x80000000 | 21, {{
            { QMetaType::QString, 22 }, { QMetaType::QStringList, 23 }, { QMetaType::QString, 24 }, { QMetaType::QString, 25 },
            { 0x80000000 | 26, 27 }, { QMetaType::QString, 28 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'List'
        QtMocHelpers::PropertyData<QList<QDBusObjectPath>>(29, 0x80000000 | 30, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ApplicationManager, qt_meta_tag_ZN18ApplicationManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ApplicationManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractInterface::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ApplicationManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ApplicationManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN18ApplicationManagerE_t>.metaTypes,
    nullptr
} };

void ApplicationManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<ApplicationManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { QDBusPendingReply<QString,QDBusObjectPath,ObjectInterfaceMap> _r = _t->Identify((*reinterpret_cast<std::add_pointer_t<QDBusUnixFileDescriptor>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString,QDBusObjectPath,ObjectInterfaceMap>*>(_a[0]) = std::move(_r); }  break;
        case 1: { QDBusReply<QString> _r = _t->Identify((*reinterpret_cast<std::add_pointer_t<QDBusUnixFileDescriptor>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusObjectPath&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<ObjectInterfaceMap&>>(_a[3])));
            if (_a[0]) *reinterpret_cast<QDBusReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 2: { QDBusPendingReply<> _r = _t->ReloadApplications();
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 3: { QDBusPendingReply<QString> _r = _t->addUserApplication((*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QString>*>(_a[0]) = std::move(_r); }  break;
        case 4: { QDBusPendingReply<> _r = _t->deleteUserApplication((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<>*>(_a[0]) = std::move(_r); }  break;
        case 5: { QDBusPendingReply<QDBusObjectPath> _r = _t->executeCommand((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QStringMap>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[6])));
            if (_a[0]) *reinterpret_cast<QDBusPendingReply<QDBusObjectPath>*>(_a[0]) = std::move(_r); }  break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 4:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QStringMap >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QList<QDBusObjectPath>*>(_v) = _t->list(); break;
        default: break;
        }
    }
}

const QMetaObject *ApplicationManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ApplicationManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN18ApplicationManagerE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractInterface::qt_metacast(_clname);
}

int ApplicationManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractInterface::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}
QT_WARNING_POP
