/****************************************************************************
** Meta object code from reading C++ file 'trayitempositionregister.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../trayitempositionregister.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'trayitempositionregister.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8docktray36TrayItemPositionRegisterAttachedTypeE_t {};
} // unnamed namespace

template <> constexpr inline auto docktray::TrayItemPositionRegisterAttachedType::qt_create_metaobjectdata<qt_meta_tag_ZN8docktray36TrayItemPositionRegisterAttachedTypeE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "docktray::TrayItemPositionRegisterAttachedType",
        "QML.Element",
        "anonymous",
        "surfaceIdChanged",
        "",
        "sectionTypeChanged",
        "visualIndexChanged",
        "visualSizeChanged",
        "QSize",
        "visualPositionChanged",
        "surfaceId",
        "sectionType",
        "visualIndex",
        "visualSize",
        "visualPosition",
        "QPoint"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'surfaceIdChanged'
        QtMocHelpers::SignalData<void(QString)>(3, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'sectionTypeChanged'
        QtMocHelpers::SignalData<void(QString)>(5, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 },
        }}),
        // Signal 'visualIndexChanged'
        QtMocHelpers::SignalData<void(int)>(6, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Signal 'visualSizeChanged'
        QtMocHelpers::SignalData<void(QSize)>(7, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 8, 4 },
        }}),
        // Signal 'visualPositionChanged'
        QtMocHelpers::SignalData<void()>(9, 4, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'surfaceId'
        QtMocHelpers::PropertyData<QString>(10, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'sectionType'
        QtMocHelpers::PropertyData<QString>(11, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'visualIndex'
        QtMocHelpers::PropertyData<int>(12, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'visualSize'
        QtMocHelpers::PropertyData<QSize>(13, 0x80000000 | 8, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 3),
        // property 'visualPosition'
        QtMocHelpers::PropertyData<QPoint>(14, 0x80000000 | 15, QMC::DefaultPropertyFlags | QMC::EnumOrFlag, 4),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<TrayItemPositionRegisterAttachedType, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject docktray::TrayItemPositionRegisterAttachedType::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8docktray36TrayItemPositionRegisterAttachedTypeE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8docktray36TrayItemPositionRegisterAttachedTypeE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8docktray36TrayItemPositionRegisterAttachedTypeE_t>.metaTypes,
    nullptr
} };

void docktray::TrayItemPositionRegisterAttachedType::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TrayItemPositionRegisterAttachedType *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->surfaceIdChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 1: _t->sectionTypeChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 2: _t->visualIndexChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 3: _t->visualSizeChanged((*reinterpret_cast<std::add_pointer_t<QSize>>(_a[1]))); break;
        case 4: _t->visualPositionChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TrayItemPositionRegisterAttachedType::*)(QString )>(_a, &TrayItemPositionRegisterAttachedType::surfaceIdChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayItemPositionRegisterAttachedType::*)(QString )>(_a, &TrayItemPositionRegisterAttachedType::sectionTypeChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayItemPositionRegisterAttachedType::*)(int )>(_a, &TrayItemPositionRegisterAttachedType::visualIndexChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayItemPositionRegisterAttachedType::*)(QSize )>(_a, &TrayItemPositionRegisterAttachedType::visualSizeChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TrayItemPositionRegisterAttachedType::*)()>(_a, &TrayItemPositionRegisterAttachedType::visualPositionChanged, 4))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QString*>(_v) = _t->m_surfaceId; break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->m_sectionType; break;
        case 2: *reinterpret_cast<int*>(_v) = _t->m_visualIndex; break;
        case 3: *reinterpret_cast<QSize*>(_v) = _t->m_visualSize; break;
        case 4: *reinterpret_cast<QPoint*>(_v) = _t->visualPosition(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_surfaceId, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->surfaceIdChanged(_t->m_surfaceId);
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_sectionType, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->sectionTypeChanged(_t->m_sectionType);
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_visualIndex, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->visualIndexChanged(_t->m_visualIndex);
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_visualSize, *reinterpret_cast<QSize*>(_v)))
                Q_EMIT _t->visualSizeChanged(_t->m_visualSize);
            break;
        default: break;
        }
    }
}

const QMetaObject *docktray::TrayItemPositionRegisterAttachedType::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *docktray::TrayItemPositionRegisterAttachedType::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8docktray36TrayItemPositionRegisterAttachedTypeE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int docktray::TrayItemPositionRegisterAttachedType::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 5;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void docktray::TrayItemPositionRegisterAttachedType::surfaceIdChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void docktray::TrayItemPositionRegisterAttachedType::sectionTypeChanged(QString _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void docktray::TrayItemPositionRegisterAttachedType::visualIndexChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void docktray::TrayItemPositionRegisterAttachedType::visualSizeChanged(QSize _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void docktray::TrayItemPositionRegisterAttachedType::visualPositionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}
namespace {
struct qt_meta_tag_ZN8docktray24TrayItemPositionRegisterE_t {};
} // unnamed namespace

template <> constexpr inline auto docktray::TrayItemPositionRegister::qt_create_metaobjectdata<qt_meta_tag_ZN8docktray24TrayItemPositionRegisterE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "docktray::TrayItemPositionRegister",
        "QML.Attached",
        "TrayItemPositionRegisterAttachedType",
        "QML.Element",
        "auto"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<TrayItemPositionRegister, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject docktray::TrayItemPositionRegister::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8docktray24TrayItemPositionRegisterE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8docktray24TrayItemPositionRegisterE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8docktray24TrayItemPositionRegisterE_t>.metaTypes,
    nullptr
} };

void docktray::TrayItemPositionRegister::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TrayItemPositionRegister *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *docktray::TrayItemPositionRegister::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *docktray::TrayItemPositionRegister::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8docktray24TrayItemPositionRegisterE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int docktray::TrayItemPositionRegister::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
