/* Generated by wayland-scanner 1.26.0 */

/*
 * SPDX-FileCopyrightText: 2026 UnionTech Software Technology Co., Ltd.
 * SPDX-License-Identifier: MIT
 */

#include <stdbool.h>
#include <stdlib.h>
#include <stdint.h>
#include "wayland-util.h"

extern const struct wl_interface treeland_keyboard_state_watcher_v1_interface;
extern const struct wl_interface wl_seat_interface;

static const struct wl_interface *treeland_keyboard_state_notify_unstable_v1_types[] = {
	NULL,
	NULL,
	&treeland_keyboard_state_watcher_v1_interface,
	&wl_seat_interface,
};

static const struct wl_message treeland_keyboard_state_notify_manager_v1_requests[] = {
	{ "destroy", "", treeland_keyboard_state_notify_unstable_v1_types + 0 },
	{ "get_keyboard_state_watcher", "n?o", treeland_keyboard_state_notify_unstable_v1_types + 2 },
};

WL_EXPORT const struct wl_interface treeland_keyboard_state_notify_manager_v1_interface = {
	"treeland_keyboard_state_notify_manager_v1", 1,
	2, treeland_keyboard_state_notify_manager_v1_requests,
	0, NULL,
};

static const struct wl_message treeland_keyboard_state_watcher_v1_requests[] = {
	{ "destroy", "", treeland_keyboard_state_notify_unstable_v1_types + 0 },
	{ "set_modifiers", "u", treeland_keyboard_state_notify_unstable_v1_types + 0 },
	{ "set_flags", "u", treeland_keyboard_state_notify_unstable_v1_types + 0 },
	{ "apply", "", treeland_keyboard_state_notify_unstable_v1_types + 0 },
};

static const struct wl_message treeland_keyboard_state_watcher_v1_events[] = {
	{ "current_state", "uu", treeland_keyboard_state_notify_unstable_v1_types + 0 },
	{ "state_changed", "uu", treeland_keyboard_state_notify_unstable_v1_types + 0 },
};

WL_EXPORT const struct wl_interface treeland_keyboard_state_watcher_v1_interface = {
	"treeland_keyboard_state_watcher_v1", 1,
	4, treeland_keyboard_state_watcher_v1_requests,
	2, treeland_keyboard_state_watcher_v1_events,
};

