/****************************************************************************
** Meta object code from reading C++ file 'waylanddockhelper.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../waylanddockhelper.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'waylanddockhelper.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4dock17WaylandDockHelperE_t {};
} // unnamed namespace

template <> constexpr inline auto dock::WaylandDockHelper::qt_create_metaobjectdata<qt_meta_tag_ZN4dock17WaylandDockHelperE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dock::WaylandDockHelper",
        "xembedWindowMoveResult",
        "",
        "uint32_t",
        "wid",
        "success",
        "setCurrentActiveWindowFullscreened"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'xembedWindowMoveResult'
        QtMocHelpers::SignalData<void(uint32_t, bool)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 }, { QMetaType::Bool, 5 },
        }}),
        // Slot 'setCurrentActiveWindowFullscreened'
        QtMocHelpers::SlotData<void(bool)>(6, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WaylandDockHelper, qt_meta_tag_ZN4dock17WaylandDockHelperE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dock::WaylandDockHelper::staticMetaObject = { {
    QMetaObject::SuperData::link<DockHelper::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock17WaylandDockHelperE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock17WaylandDockHelperE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4dock17WaylandDockHelperE_t>.metaTypes,
    nullptr
} };

void dock::WaylandDockHelper::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WaylandDockHelper *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->xembedWindowMoveResult((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->setCurrentActiveWindowFullscreened((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WaylandDockHelper::*)(uint32_t , bool )>(_a, &WaylandDockHelper::xembedWindowMoveResult, 0))
            return;
    }
}

const QMetaObject *dock::WaylandDockHelper::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dock::WaylandDockHelper::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock17WaylandDockHelperE_t>.strings))
        return static_cast<void*>(this);
    return DockHelper::qt_metacast(_clname);
}

int dock::WaylandDockHelper::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DockHelper::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void dock::WaylandDockHelper::xembedWindowMoveResult(uint32_t _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}
namespace {
struct qt_meta_tag_ZN4dock21WallpaperColorManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto dock::WallpaperColorManager::qt_create_metaobjectdata<qt_meta_tag_ZN4dock21WallpaperColorManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dock::WallpaperColorManager",
        "wallpaperColorChanged",
        "",
        "uint32_t",
        "isDark"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'wallpaperColorChanged'
        QtMocHelpers::SignalData<void(uint32_t)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 3, 4 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<WallpaperColorManager, qt_meta_tag_ZN4dock21WallpaperColorManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dock::WallpaperColorManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<WallpaperColorManager>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock21WallpaperColorManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock21WallpaperColorManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4dock21WallpaperColorManagerE_t>.metaTypes,
    nullptr
} };

void dock::WallpaperColorManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<WallpaperColorManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->wallpaperColorChanged((*reinterpret_cast<std::add_pointer_t<uint32_t>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (WallpaperColorManager::*)(uint32_t )>(_a, &WallpaperColorManager::wallpaperColorChanged, 0))
            return;
    }
}

const QMetaObject *dock::WallpaperColorManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dock::WallpaperColorManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock21WallpaperColorManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_wallpaper_color_manager_v1"))
        return static_cast< QtWayland::treeland_wallpaper_color_manager_v1*>(this);
    return QWaylandClientExtensionTemplate<WallpaperColorManager>::qt_metacast(_clname);
}

int dock::WallpaperColorManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<WallpaperColorManager>::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void dock::WallpaperColorManager::wallpaperColorChanged(uint32_t _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}
namespace {
struct qt_meta_tag_ZN4dock23TreeLandDDEShellManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto dock::TreeLandDDEShellManager::qt_create_metaobjectdata<qt_meta_tag_ZN4dock23TreeLandDDEShellManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dock::TreeLandDDEShellManager"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TreeLandDDEShellManager, qt_meta_tag_ZN4dock23TreeLandDDEShellManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dock::TreeLandDDEShellManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<TreeLandDDEShellManager>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock23TreeLandDDEShellManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock23TreeLandDDEShellManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4dock23TreeLandDDEShellManagerE_t>.metaTypes,
    nullptr
} };

void dock::TreeLandDDEShellManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TreeLandDDEShellManager *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dock::TreeLandDDEShellManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dock::TreeLandDDEShellManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock23TreeLandDDEShellManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_dde_shell_manager_v1"))
        return static_cast< QtWayland::treeland_dde_shell_manager_v1*>(this);
    return QWaylandClientExtensionTemplate<TreeLandDDEShellManager>::qt_metacast(_clname);
}

int dock::TreeLandDDEShellManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<TreeLandDDEShellManager>::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN4dock28TreeLandWindowOverlapCheckerE_t {};
} // unnamed namespace

template <> constexpr inline auto dock::TreeLandWindowOverlapChecker::qt_create_metaobjectdata<qt_meta_tag_ZN4dock28TreeLandWindowOverlapCheckerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dock::TreeLandWindowOverlapChecker"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TreeLandWindowOverlapChecker, qt_meta_tag_ZN4dock28TreeLandWindowOverlapCheckerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dock::TreeLandWindowOverlapChecker::staticMetaObject = { {
    QMetaObject::SuperData::link<QWaylandClientExtensionTemplate<TreeLandWindowOverlapChecker>::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock28TreeLandWindowOverlapCheckerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock28TreeLandWindowOverlapCheckerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4dock28TreeLandWindowOverlapCheckerE_t>.metaTypes,
    nullptr
} };

void dock::TreeLandWindowOverlapChecker::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TreeLandWindowOverlapChecker *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dock::TreeLandWindowOverlapChecker::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dock::TreeLandWindowOverlapChecker::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock28TreeLandWindowOverlapCheckerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QtWayland::treeland_window_overlap_checker"))
        return static_cast< QtWayland::treeland_window_overlap_checker*>(this);
    return QWaylandClientExtensionTemplate<TreeLandWindowOverlapChecker>::qt_metacast(_clname);
}

int dock::TreeLandWindowOverlapChecker::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWaylandClientExtensionTemplate<TreeLandWindowOverlapChecker>::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN4dock22TreeLandDockWakeUpAreaE_t {};
} // unnamed namespace

template <> constexpr inline auto dock::TreeLandDockWakeUpArea::qt_create_metaobjectdata<qt_meta_tag_ZN4dock22TreeLandDockWakeUpAreaE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dock::TreeLandDockWakeUpArea"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<TreeLandDockWakeUpArea, qt_meta_tag_ZN4dock22TreeLandDockWakeUpAreaE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dock::TreeLandDockWakeUpArea::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock22TreeLandDockWakeUpAreaE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock22TreeLandDockWakeUpAreaE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4dock22TreeLandDockWakeUpAreaE_t>.metaTypes,
    nullptr
} };

void dock::TreeLandDockWakeUpArea::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TreeLandDockWakeUpArea *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *dock::TreeLandDockWakeUpArea::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dock::TreeLandDockWakeUpArea::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock22TreeLandDockWakeUpAreaE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "DockWakeUpArea"))
        return static_cast< DockWakeUpArea*>(this);
    return QWidget::qt_metacast(_clname);
}

int dock::TreeLandDockWakeUpArea::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
