/****************************************************************************
** Meta object code from reading C++ file 'dockdbusproxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../dockdbusproxy.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dockdbusproxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4dock13DockDBusProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto dock::DockDBusProxy::qt_create_metaobjectdata<qt_meta_tag_ZN4dock13DockDBusProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dock::DockDBusProxy",
        "pluginVisibleChanged",
        "",
        "pluginName",
        "visible",
        "pluginsChanged",
        "geometry",
        "QRect",
        "FrontendWindowRect",
        "Position",
        "HideMode",
        "HideState",
        "WindowSizeEfficient",
        "WindowSizeFashion",
        "DisplayMode",
        "showInPrimary",
        "Locked"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pluginVisibleChanged'
        QtMocHelpers::SignalData<void(const QString &, bool) const>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::Bool, 4 },
        }}),
        // Signal 'pluginsChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'geometry'
        QtMocHelpers::PropertyData<QRect>(6, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final),
        // property 'FrontendWindowRect'
        QtMocHelpers::PropertyData<QRect>(8, 0x80000000 | 7, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final),
        // property 'Position'
        QtMocHelpers::PropertyData<Position>(9, 0x80000000 | 9, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final),
        // property 'HideMode'
        QtMocHelpers::PropertyData<HideMode>(10, 0x80000000 | 10, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet | QMC::Final),
        // property 'HideState'
        QtMocHelpers::PropertyData<HideState>(11, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::EnumOrFlag | QMC::Final),
        // property 'WindowSizeEfficient'
        QtMocHelpers::PropertyData<uint>(12, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'WindowSizeFashion'
        QtMocHelpers::PropertyData<uint>(13, QMetaType::UInt, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'DisplayMode'
        QtMocHelpers::PropertyData<int>(14, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final),
        // property 'showInPrimary'
        QtMocHelpers::PropertyData<bool>(15, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final),
        // property 'Locked'
        QtMocHelpers::PropertyData<bool>(16, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet | QMC::Final),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DockDBusProxy, qt_meta_tag_ZN4dock13DockDBusProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dock::DockDBusProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock13DockDBusProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock13DockDBusProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4dock13DockDBusProxyE_t>.metaTypes,
    nullptr
} };

void dock::DockDBusProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DockDBusProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pluginVisibleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->pluginsChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DockDBusProxy::*)(const QString & , bool ) const>(_a, &DockDBusProxy::pluginVisibleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockDBusProxy::*)()>(_a, &DockDBusProxy::pluginsChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QRect*>(_v) = _t->geometry(); break;
        case 1: *reinterpret_cast<QRect*>(_v) = _t->frontendWindowRect(); break;
        case 2: *reinterpret_cast<Position*>(_v) = _t->position(); break;
        case 3: *reinterpret_cast<HideMode*>(_v) = _t->hideMode(); break;
        case 4: *reinterpret_cast<HideState*>(_v) = _t->hideState(); break;
        case 5: *reinterpret_cast<uint*>(_v) = _t->windowSizeEfficient(); break;
        case 6: *reinterpret_cast<uint*>(_v) = _t->windowSizeFashion(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->displayMode(); break;
        case 8: *reinterpret_cast<bool*>(_v) = _t->showInPrimary(); break;
        case 9: *reinterpret_cast<bool*>(_v) = _t->locked(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setPosition(*reinterpret_cast<Position*>(_v)); break;
        case 3: _t->setHideMode(*reinterpret_cast<HideMode*>(_v)); break;
        case 5: _t->setWindowSizeEfficient(*reinterpret_cast<uint*>(_v)); break;
        case 6: _t->setWindowSizeFashion(*reinterpret_cast<uint*>(_v)); break;
        case 7: _t->setDisplayMode(*reinterpret_cast<int*>(_v)); break;
        case 8: _t->setShowInPrimary(*reinterpret_cast<bool*>(_v)); break;
        case 9: _t->setLocked(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *dock::DockDBusProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dock::DockDBusProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4dock13DockDBusProxyE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int dock::DockDBusProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 2;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void dock::DockDBusProxy::pluginVisibleChanged(const QString & _t1, bool _t2)const
{
    QMetaObject::activate<void>(const_cast< dock::DockDBusProxy *>(this), &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void dock::DockDBusProxy::pluginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
