/****************************************************************************
** Generated QML type registration code
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <QtQml/qqml.h>
#include <QtQml/qqmlmoduleregistration.h>

#if __has_include(<constants.h>)
#  include <constants.h>
#endif
#if __has_include(<dockpositioner.h>)
#  include <dockpositioner.h>
#endif
#if __has_include(<pluginmanagerextension_p.h>)
#  include <pluginmanagerextension_p.h>
#endif
#if __has_include(<xdgactivationmanager_p.h>)
#  include <xdgactivationmanager_p.h>
#endif


#if !defined(QT_STATIC)
#define Q_QMLTYPE_EXPORT Q_DECL_EXPORT
#else
#define Q_QMLTYPE_EXPORT
#endif
Q_QMLTYPE_EXPORT void qml_register_types_org_deepin_ds_dock()
{
    QT_WARNING_PUSH QT_WARNING_DISABLE_DEPRECATED
    qmlRegisterTypesAndRevisions<PluginManager>("org.deepin.ds.dock", 1);
    qmlRegisterTypesAndRevisions<PluginPopup>("org.deepin.ds.dock", 1);
    qmlRegisterTypesAndRevisions<PluginScaleManager>("org.deepin.ds.dock", 1);
    qmlRegisterTypesAndRevisions<PluginSurface>("org.deepin.ds.dock", 1);
    qmlRegisterTypesAndRevisions<XdgActivationManager>("org.deepin.ds.dock", 1);
    {
        Q_CONSTINIT static auto metaType = QQmlPrivate::metaTypeForNamespace(
            [](const QtPrivate::QMetaTypeInterface *) {return &dock::staticMetaObject;},
            "dock");
        QMetaType(&metaType).id();
    }
    qmlRegisterNamespaceAndRevisions(&dock::staticMetaObject, "org.deepin.ds.dock", 1, nullptr, &dock::staticMetaObject, nullptr);
    qmlRegisterEnum<dock::SIZE>("dock::SIZE");
    qmlRegisterEnum<dock::IndicatorStyle>("dock::IndicatorStyle");
    qmlRegisterEnum<dock::ItemAlignment>("dock::ItemAlignment");
    qmlRegisterEnum<dock::ColorTheme>("dock::ColorTheme");
    qmlRegisterEnum<dock::HideMode>("dock::HideMode");
    qmlRegisterEnum<dock::Position>("dock::Position");
    qmlRegisterEnum<dock::HideState>("dock::HideState");
    qmlRegisterEnum<dock::AniAction>("dock::AniAction");
    qmlRegisterEnum<dock::TrayPopupType>("dock::TrayPopupType");
    qmlRegisterEnum<dock::TrayPluginType>("dock::TrayPluginType");
    qmlRegisterEnum<dock::TrayPluginSizePolicy>("dock::TrayPluginSizePolicy");
    qmlRegisterEnum<dock::OverFlowState>("dock::OverFlowState");
    qmlRegisterTypesAndRevisions<dock::DockPanelPositioner>("org.deepin.ds.dock", 1);
    qmlRegisterTypesAndRevisions<dock::DockPositioner>("org.deepin.ds.dock", 1);
    QT_WARNING_POP
    qmlRegisterModule("org.deepin.ds.dock", 1, 0);
}

static const QQmlModuleRegistration orgdeepindsdockRegistration("org.deepin.ds.dock", qml_register_types_org_deepin_ds_dock);
