/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.desktopspec.ApplicationManager1.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * Do not edit! All changes made to it will be lost.
 */

#ifndef APPLICATIONMANAGER1INTERFACE_H
#define APPLICATIONMANAGER1INTERFACE_H

#include <QtCore/QObject>
#include <QtCore/QByteArray>
#include <QtCore/QList>
#include <QtCore/QMap>
#include <QtCore/QString>
#include <QtCore/QStringList>
#include <QtCore/QVariant>
#include <QtDBus/QtDBus>
#include "api/types/am.h"

/*
 * Proxy class for interface org.desktopspec.ApplicationManager1
 */
class ApplicationManager: public QDBusAbstractInterface
{
    Q_OBJECT
public:
    static inline const char *staticInterfaceName()
    { return "org.desktopspec.ApplicationManager1"; }

public:
    ApplicationManager(const QString &service, const QString &path, const QDBusConnection &connection, QObject *parent = nullptr);

    ~ApplicationManager();

public Q_SLOTS: // METHODS
    inline QDBusPendingReply<QString, QDBusObjectPath, ObjectInterfaceMap> Identify(const QDBusUnixFileDescriptor &pidfd)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(pidfd);
        return asyncCallWithArgumentList(QStringLiteral("Identify"), argumentList);
    }
    inline QDBusReply<QString> Identify(const QDBusUnixFileDescriptor &pidfd, QDBusObjectPath &instance, ObjectInterfaceMap &application_instance_info)
    {
        QList<QVariant> argumentList;
        argumentList << QVariant::fromValue(pidfd);
        QDBusMessage reply = callWithArgumentList(QDBus::Block, QStringLiteral("Identify"), argumentList);
        if (reply.type() == QDBusMessage::ReplyMessage && reply.arguments().size() == 3) {
            instance = qdbus_cast<QDBusObjectPath>(reply.arguments().at(1));
            application_instance_info = qdbus_cast<ObjectInterfaceMap>(reply.arguments().at(2));
        }
        return reply;
    }

Q_SIGNALS: // SIGNALS
};

namespace org {
  namespace desktopspec {
    using ApplicationManager1 = ::ApplicationManager;
  }
}

#endif
