/****************************************************************************
** Meta object code from reading C++ file 'dockfrontadaptor.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "dockfrontadaptor.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dockfrontadaptor.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16DockFrontAdaptorE_t {};
} // unnamed namespace

template <> constexpr inline auto DockFrontAdaptor::qt_create_metaobjectdata<qt_meta_tag_ZN16DockFrontAdaptorE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "DockFrontAdaptor",
        "D-Bus Interface",
        "org.deepin.dde.Dock1",
        "D-Bus Introspection",
        "  <interface name=\"org.deepin.dde.Dock1\">\n    <property access="
        "\"read\" type=\"(iiii)\" name=\"geometry\">\n      <annotation val"
        "ue=\"QRect\" name=\"org.qtproject.QtDBus.QtTypeName\"/>\n    </pro"
        "perty>\n    <property access=\"readwrite\" type=\"b\" name=\"showI"
        "nPrimary\"/>\n    <method name=\"callShow\"/>\n    <method name=\""
        "ReloadPlugins\"/>\n    <method name=\"GetLoadedPlugins\">\n      <"
        "arg direction=\"out\" type=\"as\" name=\"list\"/>\n    </method>\n"
        "    <method name=\"plugins\">\n      <arg direction=\"out\" type=\""
        "a(sssssb)\"/>\n      <annotation value=\"DockItemInfos\" name=\"or"
        "g.qtproject.QtDBus.QtTypeName.Out0\"/>\n    </method>\n    <method"
        " name=\"resizeDock\">\n      <arg direction=\"in\" type=\"i\" name"
        "=\"offset\"/>\n      <arg direction=\"in\" type=\"b\" name=\"dragg"
        "ing\"/>\n    </method>\n    <method name=\"getPluginKey\">\n      "
        "<arg direction=\"in\" type=\"s\" name=\"pluginName\"/>\n      <arg"
        " direction=\"out\" type=\"s\" name=\"key\"/>\n    </method>\n    <"
        "method name=\"getPluginVisible\">\n      <arg direction=\"in\" typ"
        "e=\"s\" name=\"pluginName\"/>\n      <arg direction=\"out\" type=\""
        "b\" name=\"visible\"/>\n    </method>\n    <method name=\"setPlugi"
        "nVisible\">\n      <arg direction=\"in\" type=\"s\" name=\"pluginN"
        "ame\"/>\n      <arg direction=\"in\" type=\"b\" name=\"visible\"/>"
        "\n    </method>\n    <method name=\"setItemOnDock\">\n      <arg d"
        "irection=\"in\" type=\"s\" name=\"settingKey\"/>\n      <arg direc"
        "tion=\"in\" type=\"s\" name=\"itemKey\"/>\n      <arg direction=\""
        "in\" type=\"b\" name=\"visible\"/>\n    </method>\n    <signal nam"
        "e=\"pluginVisibleChanged\">\n      <arg type=\"s\"/>\n      <arg t"
        "ype=\"b\"/>\n    </signal>\n    <signal name=\"pluginsChanged\"/>\n"
        "  </interface>\n",
        "pluginVisibleChanged",
        "",
        "in0",
        "in1",
        "pluginsChanged",
        "GetLoadedPlugins",
        "ReloadPlugins",
        "callShow",
        "getPluginKey",
        "pluginName",
        "getPluginVisible",
        "plugins",
        "DockItemInfos",
        "resizeDock",
        "offset",
        "dragging",
        "setItemOnDock",
        "settingKey",
        "itemKey",
        "visible",
        "setPluginVisible",
        "geometry",
        "QRect",
        "showInPrimary"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'pluginVisibleChanged'
        QtMocHelpers::SignalData<void(const QString &, bool)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 7 }, { QMetaType::Bool, 8 },
        }}),
        // Signal 'pluginsChanged'
        QtMocHelpers::SignalData<void()>(9, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'GetLoadedPlugins'
        QtMocHelpers::SlotData<QStringList()>(10, 6, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'ReloadPlugins'
        QtMocHelpers::SlotData<void()>(11, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'callShow'
        QtMocHelpers::SlotData<void()>(12, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'getPluginKey'
        QtMocHelpers::SlotData<QString(const QString &)>(13, 6, QMC::AccessPublic, QMetaType::QString, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'getPluginVisible'
        QtMocHelpers::SlotData<bool(const QString &)>(15, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 14 },
        }}),
        // Slot 'plugins'
        QtMocHelpers::SlotData<DockItemInfos()>(16, 6, QMC::AccessPublic, 0x80000000 | 17),
        // Slot 'resizeDock'
        QtMocHelpers::SlotData<void(int, bool)>(18, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 19 }, { QMetaType::Bool, 20 },
        }}),
        // Slot 'setItemOnDock'
        QtMocHelpers::SlotData<void(const QString &, const QString &, bool)>(21, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 22 }, { QMetaType::QString, 23 }, { QMetaType::Bool, 24 },
        }}),
        // Slot 'setPluginVisible'
        QtMocHelpers::SlotData<void(const QString &, bool)>(25, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::Bool, 24 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'geometry'
        QtMocHelpers::PropertyData<QRect>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::EnumOrFlag),
        // property 'showInPrimary'
        QtMocHelpers::PropertyData<bool>(28, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<DockFrontAdaptor, qt_meta_tag_ZN16DockFrontAdaptorE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject DockFrontAdaptor::staticMetaObject = { {
    QMetaObject::SuperData::link<QDBusAbstractAdaptor::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DockFrontAdaptorE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DockFrontAdaptorE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16DockFrontAdaptorE_t>.metaTypes,
    nullptr
} };

void DockFrontAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DockFrontAdaptor *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->pluginVisibleChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 1: _t->pluginsChanged(); break;
        case 2: { QStringList _r = _t->GetLoadedPlugins();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->ReloadPlugins(); break;
        case 4: _t->callShow(); break;
        case 5: { QString _r = _t->getPluginKey((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QString*>(_a[0]) = std::move(_r); }  break;
        case 6: { bool _r = _t->getPluginVisible((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 7: { DockItemInfos _r = _t->plugins();
            if (_a[0]) *reinterpret_cast<DockItemInfos*>(_a[0]) = std::move(_r); }  break;
        case 8: _t->resizeDock((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 9: _t->setItemOnDock((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3]))); break;
        case 10: _t->setPluginVisible((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DockFrontAdaptor::*)(const QString & , bool )>(_a, &DockFrontAdaptor::pluginVisibleChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DockFrontAdaptor::*)()>(_a, &DockFrontAdaptor::pluginsChanged, 1))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QRect*>(_v) = _t->geometry(); break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->showInPrimary(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 1: _t->setShowInPrimary(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *DockFrontAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *DockFrontAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16DockFrontAdaptorE_t>.strings))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int DockFrontAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    }
    return _id;
}

// SIGNAL 0
void DockFrontAdaptor::pluginVisibleChanged(const QString & _t1, bool _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void DockFrontAdaptor::pluginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
