/*
 * This file was generated by qdbusxml2cpp version 0.8
 * Source file was org.deepin.ds.dock.taskmanager.item.xml
 *
 * qdbusxml2cpp is Copyright (C) The Qt Company Ltd. and other contributors.
 *
 * This is an auto-generated file.
 * This file may have been hand-edited. Look for HAND-EDIT comments
 * before re-generating it.
 */

#ifndef ITEMADAPTOR_H
#define ITEMADAPTOR_H

#include <QtCore/QObject>
#include <QtDBus/QtDBus>
#include "appitem.h"
#include <QtCore/qcontainerfwd.h>

/*
 * Adaptor class for interface org.deepin.ds.Dock.TaskManager.Item
 */
class ItemAdaptor: public QDBusAbstractAdaptor
{
    Q_OBJECT
    Q_CLASSINFO("D-Bus Interface", "org.deepin.ds.Dock.TaskManager.Item")
    Q_CLASSINFO("D-Bus Introspection", ""
"  <interface name=\"org.deepin.ds.Dock.TaskManager.Item\">\n"
"    <property access=\"readwrite\" type=\"b\" name=\"isActive\"/>\n"
"    <property access=\"readwrite\" type=\"b\" name=\"isDocked\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"id\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"name\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"icon\"/>\n"
"    <property access=\"read\" type=\"s\" name=\"menus\"/>\n"
"    <method name=\"setDocked\">\n"
"      <arg direction=\"in\" type=\"b\" name=\"docked\"/>\n"
"    </method>\n"
"    <method name=\"handleClick\">\n"
"      <arg direction=\"in\" type=\"s\" name=\"action\"/>\n"
"    </method>\n"
"  </interface>\n"
        "")
public:
    ItemAdaptor(dock::AbstractItem *parent);
    ~ItemAdaptor() override;

    inline dock::AbstractItem *parent() const
    { return static_cast<dock::AbstractItem *>(QObject::parent()); }

public: // PROPERTIES
    Q_PROPERTY(QString icon READ icon)
    QString icon() const;

    Q_PROPERTY(QString id READ id)
    QString id() const;

    Q_PROPERTY(bool isActive READ isActive WRITE setIsActive)
    bool isActive() const;
    void setIsActive(bool value);

    Q_PROPERTY(bool isDocked READ isDocked WRITE setIsDocked)
    bool isDocked() const;
    void setIsDocked(bool value);

    Q_PROPERTY(QString menus READ menus)
    QString menus() const;

    Q_PROPERTY(QString name READ name)
    QString name() const;

public Q_SLOTS: // METHODS
    void handleClick(const QString &action);
    void setDocked(bool docked);
Q_SIGNALS: // SIGNALS
};

#endif
