/****************************************************************************
** Meta object code from reading C++ file 'appgroupmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../appgroupmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'appgroupmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN4apps12ItemPositionE_t {};
} // unnamed namespace

template <> constexpr inline auto apps::ItemPosition::qt_create_metaobjectdata<qt_meta_tag_ZN4apps12ItemPositionE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "apps::ItemPosition",
        "group",
        "page",
        "pos"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
        // property 'group'
        QtMocHelpers::PropertyData<int>(1, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'page'
        QtMocHelpers::PropertyData<int>(2, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
        // property 'pos'
        QtMocHelpers::PropertyData<int>(3, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<ItemPosition, qt_meta_tag_ZN4apps12ItemPositionE_t>(QMC::PropertyAccessInStaticMetaCall, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject apps::ItemPosition::staticMetaObject = { {
    nullptr,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4apps12ItemPositionE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4apps12ItemPositionE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4apps12ItemPositionE_t>.metaTypes,
    nullptr
} };

void apps::ItemPosition::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = reinterpret_cast<ItemPosition *>(_o);
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->m_groupId; break;
        case 1: *reinterpret_cast<int*>(_v) = _t->m_pageNumber; break;
        case 2: *reinterpret_cast<int*>(_v) = _t->m_positionInPage; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: QtMocHelpers::setProperty(_t->m_groupId, *reinterpret_cast<int*>(_v)); break;
        case 1: QtMocHelpers::setProperty(_t->m_pageNumber, *reinterpret_cast<int*>(_v)); break;
        case 2: QtMocHelpers::setProperty(_t->m_positionInPage, *reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}
namespace {
struct qt_meta_tag_ZN4apps15AppGroupManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto apps::AppGroupManager::qt_create_metaobjectdata<qt_meta_tag_ZN4apps15AppGroupManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "apps::AppGroupManager",
        "findItem",
        "ItemPosition",
        "",
        "appId",
        "folderId",
        "appendItemToGroup",
        "groupId",
        "removeItemFromGroup",
        "groupPages",
        "ItemsPage*",
        "bringToFromt",
        "id",
        "commitRearrangeOperation",
        "dragId",
        "dropId",
        "DndOperation",
        "operation",
        "pageHint",
        "DndPrepend",
        "DndJoin",
        "DndAppend"
    };

    QtMocHelpers::UintData qt_methods {
        // Method 'findItem'
        QtMocHelpers::MethodData<ItemPosition(const QString &, int)>(1, 3, QMC::AccessPublic, 0x80000000 | 2, {{
            { QMetaType::QString, 4 }, { QMetaType::Int, 5 },
        }}),
        // Method 'findItem'
        QtMocHelpers::MethodData<ItemPosition(const QString &)>(1, 3, QMC::AccessPublic | QMC::MethodCloned, 0x80000000 | 2, {{
            { QMetaType::QString, 4 },
        }}),
        // Method 'appendItemToGroup'
        QtMocHelpers::MethodData<void(const QString &, int)>(6, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 4 }, { QMetaType::Int, 7 },
        }}),
        // Method 'removeItemFromGroup'
        QtMocHelpers::MethodData<bool(const QString &, int)>(8, 3, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 4 }, { QMetaType::Int, 7 },
        }}),
        // Method 'groupPages'
        QtMocHelpers::MethodData<ItemsPage *(int)>(9, 3, QMC::AccessPublic, 0x80000000 | 10, {{
            { QMetaType::Int, 7 },
        }}),
        // Method 'bringToFromt'
        QtMocHelpers::MethodData<void(const QString &)>(11, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 12 },
        }}),
        // Method 'commitRearrangeOperation'
        QtMocHelpers::MethodData<void(const QString &, const QString &, enum DndOperation, int)>(13, 3, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 }, { 0x80000000 | 16, 17 }, { QMetaType::Int, 18 },
        }}),
        // Method 'commitRearrangeOperation'
        QtMocHelpers::MethodData<void(const QString &, const QString &, enum DndOperation)>(13, 3, QMC::AccessPublic | QMC::MethodCloned, QMetaType::Void, {{
            { QMetaType::QString, 14 }, { QMetaType::QString, 15 }, { 0x80000000 | 16, 17 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'DndOperation'
        QtMocHelpers::EnumData<enum DndOperation>(16, 16, QMC::EnumFlags{}).add({
            {   19, DndOperation::DndPrepend },
            {   20, DndOperation::DndJoin },
            {   21, DndOperation::DndAppend },
        }),
    };
    return QtMocHelpers::metaObjectData<AppGroupManager, qt_meta_tag_ZN4apps15AppGroupManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject apps::AppGroupManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QStandardItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4apps15AppGroupManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4apps15AppGroupManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN4apps15AppGroupManagerE_t>.metaTypes,
    nullptr
} };

void apps::AppGroupManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<AppGroupManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: { ItemPosition _r = _t->findItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<ItemPosition*>(_a[0]) = std::move(_r); }  break;
        case 1: { ItemPosition _r = _t->findItem((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ItemPosition*>(_a[0]) = std::move(_r); }  break;
        case 2: _t->appendItemToGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 3: { bool _r = _t->removeItemFromGroup((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 4: { ItemsPage* _r = _t->groupPages((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<ItemsPage**>(_a[0]) = std::move(_r); }  break;
        case 5: _t->bringToFromt((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->commitRearrangeOperation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<enum DndOperation>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        case 7: _t->commitRearrangeOperation((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<enum DndOperation>>(_a[3]))); break;
        default: ;
        }
    }
}

const QMetaObject *apps::AppGroupManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *apps::AppGroupManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN4apps15AppGroupManagerE_t>.strings))
        return static_cast<void*>(this);
    return QStandardItemModel::qt_metacast(_clname);
}

int apps::AppGroupManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStandardItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 8;
    }
    return _id;
}
QT_WARNING_POP
