/****************************************************************************
** Meta object code from reading C++ file 'notificationmanager.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../notificationmanager.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'notificationmanager.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN12notification19NotificationManagerE_t {};
} // unnamed namespace

template <> constexpr inline auto notification::NotificationManager::qt_create_metaobjectdata<qt_meta_tag_ZN12notification19NotificationManagerE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "notification::NotificationManager",
        "ActionInvoked",
        "",
        "id",
        "actionKey",
        "NotificationClosed",
        "reason",
        "RecordCountChanged",
        "count",
        "AppInfoChanged",
        "item",
        "QDBusVariant",
        "value",
        "SystemInfoChanged",
        "AppAdded",
        "AppRemoved",
        "NotificationStateChanged",
        "processedType",
        "ActivationToken",
        "token",
        "GetCapabilities",
        "Notify",
        "appName",
        "replacesId",
        "appIcon",
        "summary",
        "body",
        "actions",
        "QVariantMap",
        "hints",
        "expireTimeout",
        "CloseNotification",
        "GetServerInformation",
        "QString&",
        "name",
        "vendor",
        "version",
        "specVersion",
        "GetAppList",
        "SetAppInfo",
        "appId",
        "configItem",
        "QVariant",
        "GetAppInfo",
        "SetSystemInfo",
        "GetSystemInfo",
        "setBlockClosedId",
        "onHandingPendingEntities",
        "removePendingEntity",
        "NotifyEntity",
        "entity",
        "onScreenLockedChanged",
        "actionInvoked",
        "bubbleId",
        "notificationClosed",
        "notificationReplaced",
        "recordCount"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'ActionInvoked'
        QtMocHelpers::SignalData<void(uint, const QString &)>(1, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::QString, 4 },
        }}),
        // Signal 'NotificationClosed'
        QtMocHelpers::SignalData<void(uint, uint)>(5, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::UInt, 6 },
        }}),
        // Signal 'RecordCountChanged'
        QtMocHelpers::SignalData<void(uint)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 8 },
        }}),
        // Signal 'AppInfoChanged'
        QtMocHelpers::SignalData<void(const QString &, uint, const QDBusVariant &)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 }, { QMetaType::UInt, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'SystemInfoChanged'
        QtMocHelpers::SignalData<void(uint, const QDBusVariant &)>(13, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 10 }, { 0x80000000 | 11, 12 },
        }}),
        // Signal 'AppAdded'
        QtMocHelpers::SignalData<void(const QString &)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'AppRemoved'
        QtMocHelpers::SignalData<void(const QString &)>(15, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 3 },
        }}),
        // Signal 'NotificationStateChanged'
        QtMocHelpers::SignalData<void(qint64, int)>(16, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::Int, 17 },
        }}),
        // Signal 'ActivationToken'
        QtMocHelpers::SignalData<void(uint, const QString &)>(18, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 }, { QMetaType::QString, 19 },
        }}),
        // Slot 'GetCapabilities'
        QtMocHelpers::SlotData<QStringList()>(20, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'Notify'
        QtMocHelpers::SlotData<uint(const QString &, uint, const QString &, const QString &, const QString &, const QStringList &, const QVariantMap &, int)>(21, 2, QMC::AccessPublic, QMetaType::UInt, {{
            { QMetaType::QString, 22 }, { QMetaType::UInt, 23 }, { QMetaType::QString, 24 }, { QMetaType::QString, 25 },
            { QMetaType::QString, 26 }, { QMetaType::QStringList, 27 }, { 0x80000000 | 28, 29 }, { QMetaType::Int, 30 },
        }}),
        // Slot 'CloseNotification'
        QtMocHelpers::SlotData<void(uint)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 3 },
        }}),
        // Slot 'GetServerInformation'
        QtMocHelpers::SlotData<void(QString &, QString &, QString &, QString &)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 33, 34 }, { 0x80000000 | 33, 35 }, { 0x80000000 | 33, 36 }, { 0x80000000 | 33, 37 },
        }}),
        // Slot 'GetAppList'
        QtMocHelpers::SlotData<QStringList()>(38, 2, QMC::AccessPublic, QMetaType::QStringList),
        // Slot 'SetAppInfo'
        QtMocHelpers::SlotData<void(const QString &, uint, const QVariant &)>(39, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 40 }, { QMetaType::UInt, 41 }, { 0x80000000 | 42, 12 },
        }}),
        // Slot 'GetAppInfo'
        QtMocHelpers::SlotData<QVariant(const QString &, uint)>(43, 2, QMC::AccessPublic, 0x80000000 | 42, {{
            { QMetaType::QString, 40 }, { QMetaType::UInt, 41 },
        }}),
        // Slot 'SetSystemInfo'
        QtMocHelpers::SlotData<void(uint, const QVariant &)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UInt, 41 }, { 0x80000000 | 42, 12 },
        }}),
        // Slot 'GetSystemInfo'
        QtMocHelpers::SlotData<QVariant(uint)>(45, 2, QMC::AccessPublic, 0x80000000 | 42, {{
            { QMetaType::UInt, 41 },
        }}),
        // Slot 'setBlockClosedId'
        QtMocHelpers::SlotData<void(qint64)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 },
        }}),
        // Slot 'onHandingPendingEntities'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'removePendingEntity'
        QtMocHelpers::SlotData<void(const NotifyEntity &)>(48, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { 0x80000000 | 49, 50 },
        }}),
        // Slot 'onScreenLockedChanged'
        QtMocHelpers::SlotData<void(bool)>(51, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Method 'actionInvoked'
        QtMocHelpers::MethodData<void(qint64, const QString &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::QString, 4 },
        }}),
        // Method 'actionInvoked'
        QtMocHelpers::MethodData<void(qint64, uint, const QString &)>(52, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::UInt, 53 }, { QMetaType::QString, 4 },
        }}),
        // Method 'notificationClosed'
        QtMocHelpers::MethodData<void(qint64, uint, uint)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 }, { QMetaType::UInt, 53 }, { QMetaType::UInt, 6 },
        }}),
        // Method 'notificationReplaced'
        QtMocHelpers::MethodData<void(qint64)>(55, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::LongLong, 3 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'recordCount'
        QtMocHelpers::PropertyData<uint>(56, QMetaType::UInt, QMC::DefaultPropertyFlags, 2),
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<NotificationManager, qt_meta_tag_ZN12notification19NotificationManagerE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject notification::NotificationManager::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12notification19NotificationManagerE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12notification19NotificationManagerE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN12notification19NotificationManagerE_t>.metaTypes,
    nullptr
} };

void notification::NotificationManager::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<NotificationManager *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->ActionInvoked((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 1: _t->NotificationClosed((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2]))); break;
        case 2: _t->RecordCountChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 3: _t->AppInfoChanged((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[3]))); break;
        case 4: _t->SystemInfoChanged((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QDBusVariant>>(_a[2]))); break;
        case 5: _t->AppAdded((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 6: _t->AppRemoved((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 7: _t->NotificationStateChanged((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->ActivationToken((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 9: { QStringList _r = _t->GetCapabilities();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 10: { uint _r = _t->Notify((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[4])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[5])),(*reinterpret_cast<std::add_pointer_t<QStringList>>(_a[6])),(*reinterpret_cast<std::add_pointer_t<QVariantMap>>(_a[7])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[8])));
            if (_a[0]) *reinterpret_cast<uint*>(_a[0]) = std::move(_r); }  break;
        case 11: _t->CloseNotification((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1]))); break;
        case 12: _t->GetServerInformation((*reinterpret_cast<std::add_pointer_t<QString&>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<QString&>>(_a[4]))); break;
        case 13: { QStringList _r = _t->GetAppList();
            if (_a[0]) *reinterpret_cast<QStringList*>(_a[0]) = std::move(_r); }  break;
        case 14: _t->SetAppInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[3]))); break;
        case 15: { QVariant _r = _t->GetAppInfo((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 16: _t->SetSystemInfo((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QVariant>>(_a[2]))); break;
        case 17: { QVariant _r = _t->GetSystemInfo((*reinterpret_cast<std::add_pointer_t<uint>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QVariant*>(_a[0]) = std::move(_r); }  break;
        case 18: _t->setBlockClosedId((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        case 19: _t->onHandingPendingEntities(); break;
        case 20: _t->removePendingEntity((*reinterpret_cast<std::add_pointer_t<NotifyEntity>>(_a[1]))); break;
        case 21: _t->onScreenLockedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 22: _t->actionInvoked((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[2]))); break;
        case 23: _t->actionInvoked((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<QString>>(_a[3]))); break;
        case 24: _t->notificationClosed((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<uint>>(_a[3]))); break;
        case 25: _t->notificationReplaced((*reinterpret_cast<std::add_pointer_t<qint64>>(_a[1]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 3:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 2:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusVariant >(); break;
            }
            break;
        case 4:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 1:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QDBusVariant >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (NotificationManager::*)(uint , const QString & )>(_a, &NotificationManager::ActionInvoked, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationManager::*)(uint , uint )>(_a, &NotificationManager::NotificationClosed, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationManager::*)(uint )>(_a, &NotificationManager::RecordCountChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationManager::*)(const QString & , uint , const QDBusVariant & )>(_a, &NotificationManager::AppInfoChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationManager::*)(uint , const QDBusVariant & )>(_a, &NotificationManager::SystemInfoChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationManager::*)(const QString & )>(_a, &NotificationManager::AppAdded, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationManager::*)(const QString & )>(_a, &NotificationManager::AppRemoved, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationManager::*)(qint64 , int )>(_a, &NotificationManager::NotificationStateChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (NotificationManager::*)(uint , const QString & )>(_a, &NotificationManager::ActivationToken, 8))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<uint*>(_v) = _t->recordCount(); break;
        default: break;
        }
    }
}

const QMetaObject *notification::NotificationManager::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *notification::NotificationManager::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN12notification19NotificationManagerE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QDBusContext"))
        return static_cast< QDBusContext*>(this);
    return QObject::qt_metacast(_clname);
}

int notification::NotificationManager::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 26)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 26;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    return _id;
}

// SIGNAL 0
void notification::NotificationManager::ActionInvoked(uint _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1, _t2);
}

// SIGNAL 1
void notification::NotificationManager::NotificationClosed(uint _t1, uint _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1, _t2);
}

// SIGNAL 2
void notification::NotificationManager::RecordCountChanged(uint _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void notification::NotificationManager::AppInfoChanged(const QString & _t1, uint _t2, const QDBusVariant & _t3)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1, _t2, _t3);
}

// SIGNAL 4
void notification::NotificationManager::SystemInfoChanged(uint _t1, const QDBusVariant & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1, _t2);
}

// SIGNAL 5
void notification::NotificationManager::AppAdded(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void notification::NotificationManager::AppRemoved(const QString & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void notification::NotificationManager::NotificationStateChanged(qint64 _t1, int _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1, _t2);
}

// SIGNAL 8
void notification::NotificationManager::ActivationToken(uint _t1, const QString & _t2)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 8, nullptr, _t1, _t2);
}
QT_WARNING_POP
