/****************************************************************************
** Meta object code from reading C++ file 'traysortordermodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../traysortordermodel.h"
#include <QtCore/qmetatype.h>
#include <QtCore/QList>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'traysortordermodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN8docktray18TraySortOrderModelE_t {};
} // unnamed namespace

template <> constexpr inline auto docktray::TraySortOrderModel::qt_create_metaobjectdata<qt_meta_tag_ZN8docktray18TraySortOrderModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "docktray::TraySortOrderModel",
        "QML.Element",
        "auto",
        "QML.Singleton",
        "true",
        "collapsedChanged",
        "",
        "isCollapsingChanged",
        "actionsAlwaysVisibleChanged",
        "isUpdatingChanged",
        "visualItemCountChanged",
        "availableSurfacesChanged",
        "QList<QVariantMap>",
        "stagedDropChanged",
        "onAvailableSurfacesChanged",
        "dropToStashTray",
        "draggedSurfaceId",
        "dropVisualIndex",
        "isBefore",
        "dropToDockTray",
        "setSurfaceVisible",
        "surfaceId",
        "visible",
        "isDisplayedSurface",
        "setDockVisible",
        "isDockVisible",
        "getModelIndexByVisualIndex",
        "QModelIndex",
        "visualIndex",
        "stageDropPosition",
        "commitStagedDrop",
        "clearStagedDrop",
        "visualItemCount",
        "collapsed",
        "isCollapsing",
        "actionsAlwaysVisible",
        "isUpdating",
        "availableSurfaces",
        "stagedSurfaceId",
        "stagedVisualIndex",
        "Roles",
        "SurfaceIdRole",
        "VisibilityRole",
        "DockVisibleRole",
        "SectionTypeRole",
        "VisualIndexRole",
        "DelegateTypeRole",
        "ForbiddenSectionsRole",
        "PluginFlagsRole",
        "ModelExtendedRole",
        "VisualSections",
        "DockTraySection",
        "StashedSection"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'collapsedChanged'
        QtMocHelpers::SignalData<void(bool)>(5, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'isCollapsingChanged'
        QtMocHelpers::SignalData<void(bool)>(7, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'actionsAlwaysVisibleChanged'
        QtMocHelpers::SignalData<void(bool)>(8, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'isUpdatingChanged'
        QtMocHelpers::SignalData<void(bool)>(9, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 6 },
        }}),
        // Signal 'visualItemCountChanged'
        QtMocHelpers::SignalData<void(int)>(10, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 6 },
        }}),
        // Signal 'availableSurfacesChanged'
        QtMocHelpers::SignalData<void(const QList<QVariantMap> &)>(11, 6, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 12, 6 },
        }}),
        // Signal 'stagedDropChanged'
        QtMocHelpers::SignalData<void()>(13, 6, QMC::AccessPublic, QMetaType::Void),
        // Slot 'onAvailableSurfacesChanged'
        QtMocHelpers::SlotData<void()>(14, 6, QMC::AccessPrivate, QMetaType::Void),
        // Method 'dropToStashTray'
        QtMocHelpers::MethodData<bool(const QString &, int, bool)>(15, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 16 }, { QMetaType::Int, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Method 'dropToDockTray'
        QtMocHelpers::MethodData<bool(const QString &, int, bool)>(19, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 16 }, { QMetaType::Int, 17 }, { QMetaType::Bool, 18 },
        }}),
        // Method 'setSurfaceVisible'
        QtMocHelpers::MethodData<void(const QString &, bool)>(20, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::Bool, 22 },
        }}),
        // Method 'isDisplayedSurface'
        QtMocHelpers::MethodData<bool(const QString &) const>(23, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Method 'setDockVisible'
        QtMocHelpers::MethodData<void(const QString &, bool)>(24, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::Bool, 22 },
        }}),
        // Method 'isDockVisible'
        QtMocHelpers::MethodData<bool(const QString &) const>(25, 6, QMC::AccessPublic, QMetaType::Bool, {{
            { QMetaType::QString, 21 },
        }}),
        // Method 'getModelIndexByVisualIndex'
        QtMocHelpers::MethodData<QModelIndex(int) const>(26, 6, QMC::AccessPublic, 0x80000000 | 27, {{
            { QMetaType::Int, 28 },
        }}),
        // Method 'stageDropPosition'
        QtMocHelpers::MethodData<void(const QString &, int)>(29, 6, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 21 }, { QMetaType::Int, 28 },
        }}),
        // Method 'commitStagedDrop'
        QtMocHelpers::MethodData<void()>(30, 6, QMC::AccessPublic, QMetaType::Void),
        // Method 'clearStagedDrop'
        QtMocHelpers::MethodData<void()>(31, 6, QMC::AccessPublic, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'visualItemCount'
        QtMocHelpers::PropertyData<int>(32, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 4),
        // property 'collapsed'
        QtMocHelpers::PropertyData<bool>(33, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 0),
        // property 'isCollapsing'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 1),
        // property 'actionsAlwaysVisible'
        QtMocHelpers::PropertyData<bool>(35, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 2),
        // property 'isUpdating'
        QtMocHelpers::PropertyData<bool>(36, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable, 3),
        // property 'availableSurfaces'
        QtMocHelpers::PropertyData<QList<QVariantMap>>(37, 0x80000000 | 12, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 5),
        // property 'stagedSurfaceId'
        QtMocHelpers::PropertyData<QString>(38, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable, 6),
        // property 'stagedVisualIndex'
        QtMocHelpers::PropertyData<int>(39, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable, 6),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Roles'
        QtMocHelpers::EnumData<enum Roles>(40, 40, QMC::EnumFlags{}).add({
            {   41, Roles::SurfaceIdRole },
            {   42, Roles::VisibilityRole },
            {   43, Roles::DockVisibleRole },
            {   44, Roles::SectionTypeRole },
            {   45, Roles::VisualIndexRole },
            {   46, Roles::DelegateTypeRole },
            {   47, Roles::ForbiddenSectionsRole },
            {   48, Roles::PluginFlagsRole },
            {   49, Roles::ModelExtendedRole },
        }),
        // enum 'VisualSections'
        QtMocHelpers::EnumData<enum VisualSections>(50, 50, QMC::EnumFlags{}).add({
            {   51, VisualSections::DockTraySection },
            {   52, VisualSections::StashedSection },
        }),
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
            {    3,    4 },
    });
    return QtMocHelpers::metaObjectData<TraySortOrderModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject docktray::TraySortOrderModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QStandardItemModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8docktray18TraySortOrderModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8docktray18TraySortOrderModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN8docktray18TraySortOrderModelE_t>.metaTypes,
    nullptr
} };

void docktray::TraySortOrderModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<TraySortOrderModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->collapsedChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 1: _t->isCollapsingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->actionsAlwaysVisibleChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 3: _t->isUpdatingChanged((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 4: _t->visualItemCountChanged((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 5: _t->availableSurfacesChanged((*reinterpret_cast<std::add_pointer_t<QList<QVariantMap>>>(_a[1]))); break;
        case 6: _t->stagedDropChanged(); break;
        case 7: _t->onAvailableSurfacesChanged(); break;
        case 8: { bool _r = _t->dropToStashTray((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 9: { bool _r = _t->dropToDockTray((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[3])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 10: _t->setSurfaceVisible((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 11: { bool _r = _t->isDisplayedSurface((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 12: _t->setDockVisible((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<bool>>(_a[2]))); break;
        case 13: { bool _r = _t->isDockVisible((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])));
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 14: { QModelIndex _r = _t->getModelIndexByVisualIndex((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])));
            if (_a[0]) *reinterpret_cast<QModelIndex*>(_a[0]) = std::move(_r); }  break;
        case 15: _t->stageDropPosition((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 16: _t->commitStagedDrop(); break;
        case 17: _t->clearStagedDrop(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (TraySortOrderModel::*)(bool )>(_a, &TraySortOrderModel::collapsedChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (TraySortOrderModel::*)(bool )>(_a, &TraySortOrderModel::isCollapsingChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (TraySortOrderModel::*)(bool )>(_a, &TraySortOrderModel::actionsAlwaysVisibleChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (TraySortOrderModel::*)(bool )>(_a, &TraySortOrderModel::isUpdatingChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (TraySortOrderModel::*)(int )>(_a, &TraySortOrderModel::visualItemCountChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (TraySortOrderModel::*)(const QList<QVariantMap> & )>(_a, &TraySortOrderModel::availableSurfacesChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (TraySortOrderModel::*)()>(_a, &TraySortOrderModel::stagedDropChanged, 6))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = _t->m_visualItemCount; break;
        case 1: *reinterpret_cast<bool*>(_v) = _t->m_collapsed; break;
        case 2: *reinterpret_cast<bool*>(_v) = _t->m_isCollapsing; break;
        case 3: *reinterpret_cast<bool*>(_v) = _t->m_actionsAlwaysVisible; break;
        case 4: *reinterpret_cast<bool*>(_v) = _t->m_isUpdating; break;
        case 5: *reinterpret_cast<QList<QVariantMap>*>(_v) = _t->m_availableSurfaces; break;
        case 6: *reinterpret_cast<QString*>(_v) = _t->m_stagedSurfaceId; break;
        case 7: *reinterpret_cast<int*>(_v) = _t->m_stagedVisualIndex; break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0:
            if (QtMocHelpers::setProperty(_t->m_visualItemCount, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->visualItemCountChanged(_t->m_visualItemCount);
            break;
        case 1:
            if (QtMocHelpers::setProperty(_t->m_collapsed, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->collapsedChanged(_t->m_collapsed);
            break;
        case 2:
            if (QtMocHelpers::setProperty(_t->m_isCollapsing, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->isCollapsingChanged(_t->m_isCollapsing);
            break;
        case 3:
            if (QtMocHelpers::setProperty(_t->m_actionsAlwaysVisible, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->actionsAlwaysVisibleChanged(_t->m_actionsAlwaysVisible);
            break;
        case 4:
            if (QtMocHelpers::setProperty(_t->m_isUpdating, *reinterpret_cast<bool*>(_v)))
                Q_EMIT _t->isUpdatingChanged(_t->m_isUpdating);
            break;
        case 5:
            if (QtMocHelpers::setProperty(_t->m_availableSurfaces, *reinterpret_cast<QList<QVariantMap>*>(_v)))
                Q_EMIT _t->availableSurfacesChanged(_t->m_availableSurfaces);
            break;
        case 6:
            if (QtMocHelpers::setProperty(_t->m_stagedSurfaceId, *reinterpret_cast<QString*>(_v)))
                Q_EMIT _t->stagedDropChanged();
            break;
        case 7:
            if (QtMocHelpers::setProperty(_t->m_stagedVisualIndex, *reinterpret_cast<int*>(_v)))
                Q_EMIT _t->stagedDropChanged();
            break;
        default: break;
        }
    }
}

const QMetaObject *docktray::TraySortOrderModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *docktray::TraySortOrderModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN8docktray18TraySortOrderModelE_t>.strings))
        return static_cast<void*>(this);
    return QStandardItemModel::qt_metacast(_clname);
}

int docktray::TraySortOrderModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QStandardItemModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 18)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 18;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 18)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 18;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
    return _id;
}

// SIGNAL 0
void docktray::TraySortOrderModel::collapsedChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 0, nullptr, _t1);
}

// SIGNAL 1
void docktray::TraySortOrderModel::isCollapsingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 1, nullptr, _t1);
}

// SIGNAL 2
void docktray::TraySortOrderModel::actionsAlwaysVisibleChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 2, nullptr, _t1);
}

// SIGNAL 3
void docktray::TraySortOrderModel::isUpdatingChanged(bool _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 3, nullptr, _t1);
}

// SIGNAL 4
void docktray::TraySortOrderModel::visualItemCountChanged(int _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 4, nullptr, _t1);
}

// SIGNAL 5
void docktray::TraySortOrderModel::availableSurfacesChanged(const QList<QVariantMap> & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void docktray::TraySortOrderModel::stagedDropChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}
QT_WARNING_POP
