// This file is autogenerated. Changes will be overwritten.
#include "EWIEGA46WW/moc_trayitempositionmanager.cpp"
#include "EWIEGA46WW/moc_trayitempositionregister.cpp"
#include "EWIEGA46WW/moc_traysortordermodel.cpp"
