/****************************************************************************
** Meta object code from reading C++ file 'ksortfilterproxymodel.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../ksortfilterproxymodel.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'ksortfilterproxymodel.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN21KSortFilterProxyModelE_t {};
} // unnamed namespace

template <> constexpr inline auto KSortFilterProxyModel::qt_create_metaobjectdata<qt_meta_tag_ZN21KSortFilterProxyModelE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KSortFilterProxyModel",
        "QML.Element",
        "SortFilterProxyModel",
        "filterStringChanged",
        "",
        "filterRoleNameChanged",
        "sortRoleNameChanged",
        "sortOrderChanged",
        "sortColumnChanged",
        "sourceModelChanged",
        "filterRowCallbackChanged",
        "QJSValue",
        "filterColumnCallbackChanged",
        "rowCountChanged",
        "invalidateFilter",
        "syncRoleNames",
        "sourceModel",
        "QAbstractItemModel*",
        "filterString",
        "filterRowCallback",
        "filterColumnCallback",
        "filterRoleName",
        "sortRoleName",
        "sortOrder",
        "Qt::SortOrder",
        "sortColumn",
        "count"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'filterStringChanged'
        QtMocHelpers::SignalData<void()>(3, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'filterRoleNameChanged'
        QtMocHelpers::SignalData<void()>(5, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortRoleNameChanged'
        QtMocHelpers::SignalData<void()>(6, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortOrderChanged'
        QtMocHelpers::SignalData<void()>(7, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sortColumnChanged'
        QtMocHelpers::SignalData<void()>(8, 4, QMC::AccessPublic, QMetaType::Void),
        // Signal 'sourceModelChanged'
        QtMocHelpers::SignalData<void(QObject *)>(9, 4, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QObjectStar, 4 },
        }}),
        // Signal 'filterRowCallbackChanged'
        QtMocHelpers::SignalData<void(const QJSValue &)>(10, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 4 },
        }}),
        // Signal 'filterColumnCallbackChanged'
        QtMocHelpers::SignalData<void(const QJSValue &)>(12, 4, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 11, 4 },
        }}),
        // Signal 'rowCountChanged'
        QtMocHelpers::SignalData<void()>(13, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'invalidateFilter'
        QtMocHelpers::SlotData<void()>(14, 4, QMC::AccessPublic, QMetaType::Void),
        // Slot 'syncRoleNames'
        QtMocHelpers::SlotData<void()>(15, 4, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'sourceModel'
        QtMocHelpers::PropertyData<QAbstractItemModel*>(16, 0x80000000 | 17, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 5),
        // property 'filterString'
        QtMocHelpers::PropertyData<QString>(18, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 0),
        // property 'filterRowCallback'
        QtMocHelpers::PropertyData<QJSValue>(19, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 6),
        // property 'filterColumnCallback'
        QtMocHelpers::PropertyData<QJSValue>(20, 0x80000000 | 11, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'filterRoleName'
        QtMocHelpers::PropertyData<QString>(21, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 1),
        // property 'sortRoleName'
        QtMocHelpers::PropertyData<QString>(22, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'sortOrder'
        QtMocHelpers::PropertyData<Qt::SortOrder>(23, 0x80000000 | 24, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'sortColumn'
        QtMocHelpers::PropertyData<int>(25, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 4),
        // property 'count'
        QtMocHelpers::PropertyData<int>(26, QMetaType::Int, QMC::DefaultPropertyFlags, 8),
    };
    QtMocHelpers::UintData qt_enums {
    };
    QtMocHelpers::UintData qt_constructors {};
    QtMocHelpers::ClassInfos qt_classinfo({
            {    1,    2 },
    });
    return QtMocHelpers::metaObjectData<KSortFilterProxyModel, void>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums, qt_constructors, qt_classinfo);
}
Q_CONSTINIT const QMetaObject KSortFilterProxyModel::staticMetaObject = { {
    QMetaObject::SuperData::link<QSortFilterProxyModel::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KSortFilterProxyModelE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KSortFilterProxyModelE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN21KSortFilterProxyModelE_t>.metaTypes,
    nullptr
} };

void KSortFilterProxyModel::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KSortFilterProxyModel *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->filterStringChanged(); break;
        case 1: _t->filterRoleNameChanged(); break;
        case 2: _t->sortRoleNameChanged(); break;
        case 3: _t->sortOrderChanged(); break;
        case 4: _t->sortColumnChanged(); break;
        case 5: _t->sourceModelChanged((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        case 6: _t->filterRowCallbackChanged((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 7: _t->filterColumnCallbackChanged((*reinterpret_cast<std::add_pointer_t<QJSValue>>(_a[1]))); break;
        case 8: _t->rowCountChanged(); break;
        case 9: _t->invalidateFilter(); break;
        case 10: _t->syncRoleNames(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
        case 6:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        case 7:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType(); break;
            case 0:
                *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType::fromType< QJSValue >(); break;
            }
            break;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (KSortFilterProxyModel::*)()>(_a, &KSortFilterProxyModel::filterStringChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSortFilterProxyModel::*)()>(_a, &KSortFilterProxyModel::filterRoleNameChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSortFilterProxyModel::*)()>(_a, &KSortFilterProxyModel::sortRoleNameChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSortFilterProxyModel::*)()>(_a, &KSortFilterProxyModel::sortOrderChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSortFilterProxyModel::*)()>(_a, &KSortFilterProxyModel::sortColumnChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSortFilterProxyModel::*)(QObject * )>(_a, &KSortFilterProxyModel::sourceModelChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSortFilterProxyModel::*)(const QJSValue & )>(_a, &KSortFilterProxyModel::filterRowCallbackChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSortFilterProxyModel::*)(const QJSValue & )>(_a, &KSortFilterProxyModel::filterColumnCallbackChanged, 7))
            return;
        if (QtMocHelpers::indexOfMethod<void (KSortFilterProxyModel::*)()>(_a, &KSortFilterProxyModel::rowCountChanged, 8))
            return;
    }
    if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QAbstractItemModel* >(); break;
        case 3:
        case 2:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QJSValue >(); break;
        }
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<QAbstractItemModel**>(_v) = _t->sourceModel(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->filterString(); break;
        case 2: *reinterpret_cast<QJSValue*>(_v) = _t->filterRowCallback(); break;
        case 3: *reinterpret_cast<QJSValue*>(_v) = _t->filterColumnCallback(); break;
        case 4: *reinterpret_cast<QString*>(_v) = _t->filterRoleName(); break;
        case 5: *reinterpret_cast<QString*>(_v) = _t->sortRoleName(); break;
        case 6: *reinterpret_cast<Qt::SortOrder*>(_v) = _t->sortOrder(); break;
        case 7: *reinterpret_cast<int*>(_v) = _t->sortColumn(); break;
        case 8: *reinterpret_cast<int*>(_v) = _t->rowCount(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setModel(*reinterpret_cast<QAbstractItemModel**>(_v)); break;
        case 1: _t->setFilterString(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setFilterRowCallback(*reinterpret_cast<QJSValue*>(_v)); break;
        case 3: _t->setFilterColumnCallback(*reinterpret_cast<QJSValue*>(_v)); break;
        case 4: _t->setFilterRoleName(*reinterpret_cast<QString*>(_v)); break;
        case 5: _t->setSortRoleName(*reinterpret_cast<QString*>(_v)); break;
        case 6: _t->setSortOrder(*reinterpret_cast<Qt::SortOrder*>(_v)); break;
        case 7: _t->setSortColumn(*reinterpret_cast<int*>(_v)); break;
        default: break;
        }
    }
}

const QMetaObject *KSortFilterProxyModel::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KSortFilterProxyModel::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN21KSortFilterProxyModelE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    if (!strcmp(_clname, "org.qt-project.Qt.QQmlParserStatus"))
        return static_cast< QQmlParserStatus*>(this);
    return QSortFilterProxyModel::qt_metacast(_clname);
}

int KSortFilterProxyModel::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QSortFilterProxyModel::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 11)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 11;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    return _id;
}

// SIGNAL 0
void KSortFilterProxyModel::filterStringChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void KSortFilterProxyModel::filterRoleNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void KSortFilterProxyModel::sortRoleNameChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void KSortFilterProxyModel::sortOrderChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void KSortFilterProxyModel::sortColumnChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void KSortFilterProxyModel::sourceModelChanged(QObject * _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 5, nullptr, _t1);
}

// SIGNAL 6
void KSortFilterProxyModel::filterRowCallbackChanged(const QJSValue & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 6, nullptr, _t1);
}

// SIGNAL 7
void KSortFilterProxyModel::filterColumnCallbackChanged(const QJSValue & _t1)
{
    QMetaObject::activate<void>(this, &staticMetaObject, 7, nullptr, _t1);
}

// SIGNAL 8
void KSortFilterProxyModel::rowCountChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 8, nullptr);
}
QT_WARNING_POP
