/****************************************************************************
** Meta object code from reading C++ file 'dlayershellwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../layershell/dlayershellwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dlayershellwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN2ds17DLayerShellWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto ds::DLayerShellWindow::qt_create_metaobjectdata<qt_meta_tag_ZN2ds17DLayerShellWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "ds::DLayerShellWindow",
        "anchorsChanged",
        "",
        "exclusionZoneChanged",
        "marginsChanged",
        "keyboardInteractivityChanged",
        "layerChanged",
        "scopeChanged",
        "geometryHintsChanged",
        "inputRegionChanged",
        "setInputRegionRect",
        "x",
        "y",
        "width",
        "height",
        "anchors",
        "Anchors",
        "scope",
        "leftMargin",
        "rightMargin",
        "topMargin",
        "bottomMargin",
        "exclusionZone",
        "int32_t",
        "layer",
        "Layer",
        "keyboardInteractivity",
        "KeyboardInteractivity",
        "screenConfiguration",
        "ScreenConfiguration",
        "preferredWidth",
        "preferredHeight",
        "inputRegion",
        "QRegion",
        "closeOnDismissed",
        "Anchor",
        "AnchorNone",
        "AnchorTop",
        "AnchorBottom",
        "AnchorLeft",
        "AnchorRight",
        "LayerBackground",
        "LayerButtom",
        "LayerTop",
        "LayerOverlay",
        "KeyboardInteractivityNone",
        "KeyboardInteractivityExclusive",
        "KeyboardInteractivityOnDemand"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'anchorsChanged'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'exclusionZoneChanged'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'marginsChanged'
        QtMocHelpers::SignalData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'keyboardInteractivityChanged'
        QtMocHelpers::SignalData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'layerChanged'
        QtMocHelpers::SignalData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'scopeChanged'
        QtMocHelpers::SignalData<void()>(7, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'geometryHintsChanged'
        QtMocHelpers::SignalData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'inputRegionChanged'
        QtMocHelpers::SignalData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Method 'setInputRegionRect'
        QtMocHelpers::MethodData<void(int, int, int, int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 }, { QMetaType::Int, 12 }, { QMetaType::Int, 13 }, { QMetaType::Int, 14 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
        // property 'anchors'
        QtMocHelpers::PropertyData<Anchors>(15, 0x80000000 | 16, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 0),
        // property 'scope'
        QtMocHelpers::PropertyData<QString>(17, QMetaType::QString, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
        // property 'leftMargin'
        QtMocHelpers::PropertyData<int>(18, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'rightMargin'
        QtMocHelpers::PropertyData<int>(19, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'topMargin'
        QtMocHelpers::PropertyData<int>(20, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'bottomMargin'
        QtMocHelpers::PropertyData<int>(21, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet, 2),
        // property 'exclusionZone'
        QtMocHelpers::PropertyData<int32_t>(22, 0x80000000 | 23, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag, 1),
        // property 'layer'
        QtMocHelpers::PropertyData<enum Layer>(24, 0x80000000 | 25, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 4),
        // property 'keyboardInteractivity'
        QtMocHelpers::PropertyData<enum KeyboardInteractivity>(26, 0x80000000 | 27, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet, 3),
        // property 'screenConfiguration'
        QtMocHelpers::PropertyData<enum ScreenConfiguration>(28, 0x80000000 | 29, QMC::DefaultPropertyFlags | QMC::Writable | QMC::EnumOrFlag | QMC::StdCppSet),
        // property 'preferredWidth'
        QtMocHelpers::PropertyData<int>(30, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 6),
        // property 'preferredHeight'
        QtMocHelpers::PropertyData<int>(31, QMetaType::Int, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::StdCppSet, 6),
        // property 'inputRegion'
        QtMocHelpers::PropertyData<QRegion>(32, 0x80000000 | 33, QMC::DefaultPropertyFlags | QMC::Writable | QMC::Resettable | QMC::EnumOrFlag | QMC::StdCppSet, 7),
        // property 'closeOnDismissed'
        QtMocHelpers::PropertyData<bool>(34, QMetaType::Bool, QMC::DefaultPropertyFlags | QMC::Writable | QMC::StdCppSet),
    };
    QtMocHelpers::UintData qt_enums {
        // enum 'Anchor'
        QtMocHelpers::EnumData<enum Anchor>(35, 35, QMC::EnumFlags{}).add({
            {   36, Anchor::AnchorNone },
            {   37, Anchor::AnchorTop },
            {   38, Anchor::AnchorBottom },
            {   39, Anchor::AnchorLeft },
            {   40, Anchor::AnchorRight },
        }),
        // enum 'Layer'
        QtMocHelpers::EnumData<enum Layer>(25, 25, QMC::EnumFlags{}).add({
            {   41, Layer::LayerBackground },
            {   42, Layer::LayerButtom },
            {   43, Layer::LayerTop },
            {   44, Layer::LayerOverlay },
        }),
        // enum 'KeyboardInteractivity'
        QtMocHelpers::EnumData<enum KeyboardInteractivity>(27, 27, QMC::EnumFlags{}).add({
            {   45, KeyboardInteractivity::KeyboardInteractivityNone },
            {   46, KeyboardInteractivity::KeyboardInteractivityExclusive },
            {   47, KeyboardInteractivity::KeyboardInteractivityOnDemand },
        }),
    };
    return QtMocHelpers::metaObjectData<DLayerShellWindow, qt_meta_tag_ZN2ds17DLayerShellWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject ds::DLayerShellWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2ds17DLayerShellWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2ds17DLayerShellWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN2ds17DLayerShellWindowE_t>.metaTypes,
    nullptr
} };

void ds::DLayerShellWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DLayerShellWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->anchorsChanged(); break;
        case 1: _t->exclusionZoneChanged(); break;
        case 2: _t->marginsChanged(); break;
        case 3: _t->keyboardInteractivityChanged(); break;
        case 4: _t->layerChanged(); break;
        case 5: _t->scopeChanged(); break;
        case 6: _t->geometryHintsChanged(); break;
        case 7: _t->inputRegionChanged(); break;
        case 8: _t->setInputRegionRect((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[4]))); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (DLayerShellWindow::*)()>(_a, &DLayerShellWindow::anchorsChanged, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (DLayerShellWindow::*)()>(_a, &DLayerShellWindow::exclusionZoneChanged, 1))
            return;
        if (QtMocHelpers::indexOfMethod<void (DLayerShellWindow::*)()>(_a, &DLayerShellWindow::marginsChanged, 2))
            return;
        if (QtMocHelpers::indexOfMethod<void (DLayerShellWindow::*)()>(_a, &DLayerShellWindow::keyboardInteractivityChanged, 3))
            return;
        if (QtMocHelpers::indexOfMethod<void (DLayerShellWindow::*)()>(_a, &DLayerShellWindow::layerChanged, 4))
            return;
        if (QtMocHelpers::indexOfMethod<void (DLayerShellWindow::*)()>(_a, &DLayerShellWindow::scopeChanged, 5))
            return;
        if (QtMocHelpers::indexOfMethod<void (DLayerShellWindow::*)()>(_a, &DLayerShellWindow::geometryHintsChanged, 6))
            return;
        if (QtMocHelpers::indexOfMethod<void (DLayerShellWindow::*)()>(_a, &DLayerShellWindow::inputRegionChanged, 7))
            return;
    }
    if (_c == QMetaObject::ReadProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<Anchors*>(_v) = _t->anchors(); break;
        case 1: *reinterpret_cast<QString*>(_v) = _t->scope(); break;
        case 2: *reinterpret_cast<int*>(_v) = _t->leftMargin(); break;
        case 3: *reinterpret_cast<int*>(_v) = _t->rightMargin(); break;
        case 4: *reinterpret_cast<int*>(_v) = _t->topMargin(); break;
        case 5: *reinterpret_cast<int*>(_v) = _t->bottomMargin(); break;
        case 6: *reinterpret_cast<int32_t*>(_v) = _t->exclusionZone(); break;
        case 7: *reinterpret_cast<enum Layer*>(_v) = _t->layer(); break;
        case 8: *reinterpret_cast<enum KeyboardInteractivity*>(_v) = _t->keyboardInteractivity(); break;
        case 9: *reinterpret_cast<enum ScreenConfiguration*>(_v) = _t->screenConfiguration(); break;
        case 10: *reinterpret_cast<int*>(_v) = _t->preferredWidth(); break;
        case 11: *reinterpret_cast<int*>(_v) = _t->preferredHeight(); break;
        case 12: *reinterpret_cast<QRegion*>(_v) = _t->inputRegion(); break;
        case 13: *reinterpret_cast<bool*>(_v) = _t->closeOnDismissed(); break;
        default: break;
        }
    }
    if (_c == QMetaObject::WriteProperty) {
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setAnchors(*reinterpret_cast<Anchors*>(_v)); break;
        case 1: _t->setScope(*reinterpret_cast<QString*>(_v)); break;
        case 2: _t->setLeftMargin(*reinterpret_cast<int*>(_v)); break;
        case 3: _t->setRightMargin(*reinterpret_cast<int*>(_v)); break;
        case 4: _t->setTopMargin(*reinterpret_cast<int*>(_v)); break;
        case 5: _t->setBottomMargin(*reinterpret_cast<int*>(_v)); break;
        case 6: _t->setExclusiveZone(*reinterpret_cast<int32_t*>(_v)); break;
        case 7: _t->setLayer(*reinterpret_cast<enum Layer*>(_v)); break;
        case 8: _t->setKeyboardInteractivity(*reinterpret_cast<enum KeyboardInteractivity*>(_v)); break;
        case 9: _t->setScreenConfiguration(*reinterpret_cast<enum ScreenConfiguration*>(_v)); break;
        case 10: _t->setPreferredWidth(*reinterpret_cast<int*>(_v)); break;
        case 11: _t->setPreferredHeight(*reinterpret_cast<int*>(_v)); break;
        case 12: _t->setInputRegion(*reinterpret_cast<QRegion*>(_v)); break;
        case 13: _t->setCloseOnDismissed(*reinterpret_cast<bool*>(_v)); break;
        default: break;
        }
    }
    if (_c == QMetaObject::ResetProperty) {
        switch (_id) {
        case 10: _t->resetPreferredWidth(); break;
        case 11: _t->resetPreferredHeight(); break;
        case 12: _t->resetInputRegion(); break;
        default: break;
        }
    }
}

const QMetaObject *ds::DLayerShellWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *ds::DLayerShellWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN2ds17DLayerShellWindowE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int ds::DLayerShellWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 9)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 9;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 9)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 9;
    }
    if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::BindableProperty
            || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    return _id;
}

// SIGNAL 0
void ds::DLayerShellWindow::anchorsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void ds::DLayerShellWindow::exclusionZoneChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void ds::DLayerShellWindow::marginsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}

// SIGNAL 3
void ds::DLayerShellWindow::keyboardInteractivityChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 3, nullptr);
}

// SIGNAL 4
void ds::DLayerShellWindow::layerChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 4, nullptr);
}

// SIGNAL 5
void ds::DLayerShellWindow::scopeChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 5, nullptr);
}

// SIGNAL 6
void ds::DLayerShellWindow::geometryHintsChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 6, nullptr);
}

// SIGNAL 7
void ds::DLayerShellWindow::inputRegionChanged()
{
    QMetaObject::activate(this, &staticMetaObject, 7, nullptr);
}
QT_WARNING_POP
